"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QCompleter(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qcompleter.html

    **Detailed Description**

    You can use QCompleter to provide auto completions in any Qt widget, such as
    **QLineEdit**  and **QComboBox** . When the user starts typing a word,
    QCompleter suggests possible ways of completing the word, based on a word
    list. The word list is provided as a **QAbstractItemModel** . (For simple
    applications, where the word list is static, you can pass a **QStringList**
    to QCompleter's constructor.)

    **Basic Usage**

    A QCompleter is used typically with a **QLineEdit**  or **QComboBox** . For
    example, here's how to provide auto completions from a simple word list in a
    **QLineEdit** :

    **QStringList**  wordList;
        wordList << "alpha" << "omega" << "omicron"
    << "zeta";

        **QLineEdit**  *lineEdit = new **QLineEdit** (this);
    **QCompleter**  *completer = new **QCompleter** (wordList, this);
    completer->setCaseSensitivity(Qt::CaseInsensitive);
    lineEdit->setCompleter(completer);

    A **QFileSystemModel**  can be used to provide auto completion of file
    names. For example:

    **QCompleter**  *completer = new **QCompleter** (this);
    completer->setModel(new **QFileSystemModel** (completer));
    lineEdit->setCompleter(completer);

    To set the model on which QCompleter should operate, call **setModel** ().
    By default, QCompleter will attempt to match the **completion prefix**
    (i.e., the word that the user has started typing) against the
    **Qt::EditRole**  data stored in column 0 in the model case sensitively.
    This can be changed using **setCompletionRole** (), **setCompletionColumn**
    (), and **setCaseSensitivity** ().

    If the model is sorted on the column and role that are used for completion,
    you can call **setModelSorting** () with either
    **QCompleter::CaseSensitivelySortedModel**  or
    **QCompleter::CaseInsensitivelySortedModel**  as the argument. On large
    models, this can lead to significant performance improvements, because
    QCompleter can then use binary search instead of linear search. The binary
    search only works when the **filterMode**  is **Qt::MatchStartsWith** .

    The model can be a **list model** , a **table model** , or a **tree model**
    . Completion on tree models is slightly more involved and is covered in the
    **Handling Tree Models**  section below.

    The **completionMode** () determines the mode used to provide completions to
    the user.

    **Iterating Through Completions**

    To retrieve a single candidate string, call **setCompletionPrefix** () with
    the text that needs to be completed and call **currentCompletion** (). You
    can iterate through the list of completions as below:

    for (int i = 0; completer->setCurrentRow(i); i++)
            **qDebug** () <<
    completer->currentCompletion() << " is match number " << i;

    **completionCount** () returns the total number of completions for the
    current prefix. **completionCount** () should be avoided when possible,
    since it requires a scan of the entire model.

    **The Completion Model**

    **completionModel** () return a list model that contains all possible
    completions for the current completion prefix, in the order in which they
    appear in the model. This model can be used to display the current
    completions in a custom view. Calling **setCompletionPrefix** ()
    automatically refreshes the completion model.

    **Handling Tree Models**

    QCompleter can look for completions in tree models, assuming that any item
    (or sub-item or sub-sub-item) can be unambiguously represented as a string
    by specifying the path to the item. The completion is then performed one
    level at a time.

    Let's take the example of a user typing in a file system path. The model is
    a (hierarchical) **QFileSystemModel** . The completion occurs for every
    element in the path. For example, if the current text is `C:\\Wind`,
    QCompleter might suggest `Windows` to complete the current path element.
    Similarly, if the current text is `C:\\Windows\\Sy`, QCompleter might suggest
    `System`.

    For this kind of completion to work, QCompleter needs to be able to split
    the path into a list of strings that are matched at each level. For
    `C:\\Windows\\Sy`, it needs to be split as "C:", "Windows" and "Sy". The
    default implementation of **splitPath** (), splits the **completionPrefix**
    using **QDir::separator** () if the model is a **QFileSystemModel** .

    To provide completions, QCompleter needs to know the path from an index.
    This is provided by **pathFromIndex** (). The default implementation of
    **pathFromIndex** (), returns the data for the **edit role**  for list
    models and the absolute file path if the mode is a **QFileSystemModel** .

    **See also** **QAbstractItemModel** , **QLineEdit** , **QComboBox** , and
    **Completer Example** .
    """

    class ModelSorting(enum.Enum):
        UnsortedModel: QCompleter = ...
        CaseSensitivelySortedModel: QCompleter = ...
        CaseInsensitivelySortedModel: QCompleter = ...

    class CompletionMode(enum.Enum):
        PopupCompletion: QCompleter = ...
        UnfilteredPopupCompletion: QCompleter = ...
        InlineCompletion: QCompleter = ...

    @typing.overload
    def __init__(
        self,
        model: QtCore.QAbstractItemModel,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#QCompleter

        **QCompleter::QCompleter(QObject * parent = nullptr)**

        Constructs a completer object with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, list: typing.Iterable[str], parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#QCompleter-1

        **QCompleter::QCompleter(QAbstractItemModel * model , QObject * parent =
        nullptr)**

        Constructs a completer object with the given **parent** that provides
        completions from the specified **model**.
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#QCompleter-2

        **QCompleter::QCompleter(const QStringList & list , QObject * parent =
        nullptr)**

        Constructs a QCompleter object with the given **parent** that uses the
        specified **list** as a source of possible completions.
        """
        ...

    def filterMode(self) -> QtCore.Qt.MatchFlag:
        """
        https://doc.qt.io/qt-6/qcompleter.html#filterMode-prop

        **[since 5.2] filterMode : Qt::MatchFlags**

        This property controls how filtering is performed.

        If filterMode is set to **Qt::MatchStartsWith** , only those entries
        that start with the typed characters will be displayed.
        **Qt::MatchContains**  will display the entries that contain the typed
        characters, and **Qt::MatchEndsWith**  the ones that end with the typed
        characters.

        Setting filterMode to any other **Qt::MatchFlag**  will issue a warning,
        and no action will be performed. Because of this, the
        `Qt::MatchCaseSensitive` flag has no effect. Use the **caseSensitivity**
        property to control case sensitivity.

        The default mode is **Qt::MatchStartsWith** .

        This property was introduced in Qt 5.2.

        **Access functions:**

        Qt::MatchFlags **filterMode** () const
        void **setFilterMode**
        (Qt::MatchFlags **filterMode** )

        **See also** **caseSensitivity** .
        """
        ...

    def setFilterMode(self, filterMode: QtCore.Qt.MatchFlag) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#filterMode-prop

        **[since 5.2] filterMode : Qt::MatchFlags**

        This property controls how filtering is performed.

        If filterMode is set to **Qt::MatchStartsWith** , only those entries
        that start with the typed characters will be displayed.
        **Qt::MatchContains**  will display the entries that contain the typed
        characters, and **Qt::MatchEndsWith**  the ones that end with the typed
        characters.

        Setting filterMode to any other **Qt::MatchFlag**  will issue a warning,
        and no action will be performed. Because of this, the
        `Qt::MatchCaseSensitive` flag has no effect. Use the **caseSensitivity**
        property to control case sensitivity.

        The default mode is **Qt::MatchStartsWith** .

        This property was introduced in Qt 5.2.

        **Access functions:**

        Qt::MatchFlags **filterMode** () const
        void **setFilterMode**
        (Qt::MatchFlags **filterMode** )

        **See also** **caseSensitivity** .
        """
        ...

    def setMaxVisibleItems(self, maxItems: int) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#maxVisibleItems-prop

        **maxVisibleItems : int**

        This property holds the maximum allowed size on screen of the completer,
        measured in items

        By default, this property has a value of 7.

        **Access functions:**

        int **maxVisibleItems** () const
        void **setMaxVisibleItems** (int
        **maxItems** )
        """
        ...

    def maxVisibleItems(self) -> int:
        """
        https://doc.qt.io/qt-6/qcompleter.html#maxVisibleItems-prop

        **maxVisibleItems : int**

        This property holds the maximum allowed size on screen of the completer,
        measured in items

        By default, this property has a value of 7.

        **Access functions:**

        int **maxVisibleItems** () const
        void **setMaxVisibleItems** (int
        **maxItems** )
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qcompleter.html#event

        **[override virtual protected] bool QCompleter::event(QEvent * ev )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def eventFilter(self, o: QtCore.QObject, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qcompleter.html#eventFilter

        **[override virtual protected] bool QCompleter::eventFilter(QObject * o
        , QEvent * e )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def setWrapAround(self, wrap: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#wrapAround-prop

        **wrapAround : bool**

        This property holds the completions wrap around when navigating through
        items

        The default is true.

        **Access functions:**

        bool **wrapAround** () const
        void **setWrapAround** (bool **wrap** )

        **Member Function Documentation**
        """
        ...

    def setCompletionPrefix(self, prefix: str) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionPrefix-prop

        **completionPrefix : QString**

        This property holds the completion prefix used to provide completions.

        The **completionModel** () is updated to reflect the list of possible
        matches for **prefix**.

        **Access functions:**

        QString **completionPrefix** () const
        void **setCompletionPrefix**
        (const QString & **prefix** )
        """
        ...

    def complete(self, rect: QtCore.QRect = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#complete

        **[slot] void QCompleter::complete(const QRect & rect = QRect())**

        For **QCompleter::PopupCompletion**  and
        QCompletion::UnfilteredPopupCompletion modes, calling this function
        displays the popup displaying the current completions. By default, if
        **rect** is not specified, the popup is displayed on the bottom of the
        **widget** (). If **rect** is specified the popup is displayed on the
        left edge of the rectangle.

        For **QCompleter::InlineCompletion**  mode, the **highlighted** ()
        signal is fired with the current completion.
        """
        ...

    def wrapAround(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcompleter.html#wrapAround-prop

        **wrapAround : bool**

        This property holds the completions wrap around when navigating through
        items

        The default is true.

        **Access functions:**

        bool **wrapAround** () const
        void **setWrapAround** (bool **wrap** )

        **Member Function Documentation**
        """
        ...

    def splitPath(self, path: str) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcompleter.html#splitPath

        **[virtual] QStringList QCompleter::splitPath(const QString & path )
        const**

        Splits the given **path** into strings that are used to match at each
        level in the **model** ().

        The default implementation of splitPath() splits a file system path
        based on **QDir::separator** () when the sourceModel() is a
        **QFileSystemModel** .

        When used with list models, the first item in the returned list is used
        for matching.

        **See also** **pathFromIndex** () and **Handling Tree Models** .
        """
        ...

    def pathFromIndex(self, index: QtCore.QModelIndex) -> str:
        """
        https://doc.qt.io/qt-6/qcompleter.html#pathFromIndex

        **[virtual] QString QCompleter::pathFromIndex(const QModelIndex & index
        ) const**

        Returns the path for the given **index**. The completer object uses this
        to obtain the completion text from the underlying model.

        The default implementation returns the **edit role**  of the item for
        list models. It returns the absolute file path if the model is a
        **QFileSystemModel** .

        **See also** **splitPath** ().
        """
        ...

    def completionPrefix(self) -> str:
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionPrefix-prop

        **completionPrefix : QString**

        This property holds the completion prefix used to provide completions.

        The **completionModel** () is updated to reflect the list of possible
        matches for **prefix**.

        **Access functions:**

        QString **completionPrefix** () const
        void **setCompletionPrefix**
        (const QString & **prefix** )
        """
        ...

    def completionModel(self) -> QtCore.QAbstractItemModel:
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionModel

        **QAbstractItemModel *QCompleter::completionModel() const**

        Returns the completion model. The completion model is a read-only list
        model that contains all the possible matches for the current completion
        prefix. The completion model is auto-updated to reflect the current
        completions.

        **Note:** The return value of this function is defined to be an
        **QAbstractItemModel**  purely for generality. This actual kind of model
        returned is an instance of an **QAbstractProxyModel**  subclass.

        **See also** **completionPrefix**  and **model** ().
        """
        ...

    def currentCompletion(self) -> str:
        """
        https://doc.qt.io/qt-6/qcompleter.html#currentCompletion

        **QString QCompleter::currentCompletion() const**

        Returns the current completion string. This includes the
        **completionPrefix** . When used alongside **setCurrentRow** (), it can
        be used to iterate through all the matches.

        **See also** **setCurrentRow** () and **currentIndex** ().
        """
        ...

    def currentIndex(self) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qcompleter.html#currentIndex

        **QModelIndex QCompleter::currentIndex() const**

        Returns the model index of the current completion in the
        **completionModel** ().

        **See also** **setCurrentRow** (), **currentCompletion** (), and
        **model** ().
        """
        ...

    def currentRow(self) -> int:
        """
        https://doc.qt.io/qt-6/qcompleter.html#currentRow

        **int QCompleter::currentRow() const**

        Returns the current row.

        **See also** **setCurrentRow** ().
        """
        ...

    def setCurrentRow(self, row: int) -> bool:
        """
        https://doc.qt.io/qt-6/qcompleter.html#setCurrentRow

        **bool QCompleter::setCurrentRow(int row )**

        Sets the current row to the **row** specified. Returns `true` if
        successful; otherwise returns `false`.

        This function may be used along with **currentCompletion** () to iterate
        through all the possible completions.

        **See also** **currentRow** (), **currentCompletion** (), and
        **completionCount** ().
        """
        ...

    def completionCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionCount

        **int QCompleter::completionCount() const**

        Returns the number of completions for the current prefix. For an
        unsorted model with a large number of items this can be expensive. Use
        **setCurrentRow** () and **currentCompletion** () to iterate through all
        the completions.
        """
        ...

    def completionRole(self) -> int:
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionRole-prop

        **completionRole : int**

        This property holds the item role to be used to query the contents of
        items for matching.

        The default role is **Qt::EditRole** .

        **Access functions:**

        int **completionRole** () const
        void **setCompletionRole** (int
        **role** )

        **See also** **completionColumn**  and **caseSensitivity** .
        """
        ...

    def setCompletionRole(self, role: int) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionRole-prop

        **completionRole : int**

        This property holds the item role to be used to query the contents of
        items for matching.

        The default role is **Qt::EditRole** .

        **Access functions:**

        int **completionRole** () const
        void **setCompletionRole** (int
        **role** )

        **See also** **completionColumn**  and **caseSensitivity** .
        """
        ...

    def completionColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionColumn-prop

        **completionColumn : int**

        This property holds the column in the model in which completions are
        searched for.

        If the **popup** () is a **QListView** , it is automatically setup to
        display this column.

        By default, the match column is 0.

        **Access functions:**

        int **completionColumn** () const
        void **setCompletionColumn** (int
        **column** )

        **See also** **completionRole**  and **caseSensitivity** .
        """
        ...

    def setCompletionColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionColumn-prop

        **completionColumn : int**

        This property holds the column in the model in which completions are
        searched for.

        If the **popup** () is a **QListView** , it is automatically setup to
        display this column.

        By default, the match column is 0.

        **Access functions:**

        int **completionColumn** () const
        void **setCompletionColumn** (int
        **column** )

        **See also** **completionRole**  and **caseSensitivity** .
        """
        ...

    def modelSorting(self) -> "QCompleter.ModelSorting":
        """
        https://doc.qt.io/qt-6/qcompleter.html#modelSorting-prop

        **modelSorting : ModelSorting**

        This property holds the way the model is sorted

        By default, no assumptions are made about the order of the items in the
        model that provides the completions.

        If the model's data for the **completionColumn** () and
        **completionRole** () is sorted in ascending order, you can set this
        property to **CaseSensitivelySortedModel**  or
        **CaseInsensitivelySortedModel** . On large models, this can lead to
        significant performance improvements because the completer object can
        then use a binary search algorithm instead of linear search algorithm.

        The sort order (i.e ascending or descending order) of the model is
        determined dynamically by inspecting the contents of the model.

        **Note:** The performance improvements described above cannot take place
        when the completer's **caseSensitivity**  is different to the case
        sensitivity used by the model's when sorting.

        **Access functions:**

        QCompleter::ModelSorting **modelSorting** () const
        void
        **setModelSorting** (QCompleter::ModelSorting **sorting** )

        **See also** **setCaseSensitivity** () and **QCompleter::ModelSorting**
        .
        """
        ...

    def setModelSorting(self, sorting: "QCompleter.ModelSorting") -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#modelSorting-prop

        **modelSorting : ModelSorting**

        This property holds the way the model is sorted

        By default, no assumptions are made about the order of the items in the
        model that provides the completions.

        If the model's data for the **completionColumn** () and
        **completionRole** () is sorted in ascending order, you can set this
        property to **CaseSensitivelySortedModel**  or
        **CaseInsensitivelySortedModel** . On large models, this can lead to
        significant performance improvements because the completer object can
        then use a binary search algorithm instead of linear search algorithm.

        The sort order (i.e ascending or descending order) of the model is
        determined dynamically by inspecting the contents of the model.

        **Note:** The performance improvements described above cannot take place
        when the completer's **caseSensitivity**  is different to the case
        sensitivity used by the model's when sorting.

        **Access functions:**

        QCompleter::ModelSorting **modelSorting** () const
        void
        **setModelSorting** (QCompleter::ModelSorting **sorting** )

        **See also** **setCaseSensitivity** () and **QCompleter::ModelSorting**
        .
        """
        ...

    def caseSensitivity(self) -> QtCore.Qt.CaseSensitivity:
        """
        https://doc.qt.io/qt-6/qcompleter.html#caseSensitivity-prop

        **caseSensitivity : Qt::CaseSensitivity**

        This property holds the case sensitivity of the matching

        The default value is `Qt::CaseSensitive`.

        **Access functions:**

        Qt::CaseSensitivity **caseSensitivity** () const
        void
        **setCaseSensitivity** (Qt::CaseSensitivity **caseSensitivity** )

        **See also** **completionColumn** , **completionRole** ,
        **modelSorting** , and **filterMode** .
        """
        ...

    def setCaseSensitivity(self, caseSensitivity: QtCore.Qt.CaseSensitivity) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#caseSensitivity-prop

        **caseSensitivity : Qt::CaseSensitivity**

        This property holds the case sensitivity of the matching

        The default value is `Qt::CaseSensitive`.

        **Access functions:**

        Qt::CaseSensitivity **caseSensitivity** () const
        void
        **setCaseSensitivity** (Qt::CaseSensitivity **caseSensitivity** )

        **See also** **completionColumn** , **completionRole** ,
        **modelSorting** , and **filterMode** .
        """
        ...

    def setPopup(self, popup: QAbstractItemView) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#setPopup

        **void QCompleter::setPopup(QAbstractItemView * popup )**

        Sets the popup used to display completions to **popup**. **QCompleter**
        takes ownership of the view.

        A **QListView**  is automatically created when the **completionMode** ()
        is set to **QCompleter::PopupCompletion**  or
        **QCompleter::UnfilteredPopupCompletion** . The default popup displays
        the **completionColumn** ().

        Ensure that this function is called before the view settings are
        modified. This is required since view's properties may require that a
        model has been set on the view (for example, hiding columns in the view
        requires a model to be set on the view).

        **See also** **popup** ().
        """
        ...

    def popup(self) -> QAbstractItemView:
        """
        https://doc.qt.io/qt-6/qcompleter.html#popup

        **QAbstractItemView *QCompleter::popup() const**

        Returns the popup used to display completions.

        **See also** **setPopup** ().
        """
        ...

    def completionMode(self) -> "QCompleter.CompletionMode":
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionMode-prop

        **completionMode : CompletionMode**

        how the completions are provided to the user

        The default value is **QCompleter::PopupCompletion** .

        **Access functions:**

        QCompleter::CompletionMode **completionMode** () const
        void
        **setCompletionMode** (QCompleter::CompletionMode **mode** )
        """
        ...

    def setCompletionMode(self, mode: "QCompleter.CompletionMode") -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#completionMode-prop

        **completionMode : CompletionMode**

        how the completions are provided to the user

        The default value is **QCompleter::PopupCompletion** .

        **Access functions:**

        QCompleter::CompletionMode **completionMode** () const
        void
        **setCompletionMode** (QCompleter::CompletionMode **mode** )
        """
        ...

    def model(self) -> QtCore.QAbstractItemModel:
        """
        https://doc.qt.io/qt-6/qcompleter.html#model

        **QAbstractItemModel *QCompleter::model() const**

        Returns the model that provides completion strings.

        **See also** **setModel** () and **completionModel** ().
        """
        ...

    def setModel(self, c: QtCore.QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#setModel

        **void QCompleter::setModel(QAbstractItemModel * model )**

        Sets the model which provides completions to **model**. The **model**
        can be list model or a tree model. If a model has been already
        previously set and it has the **QCompleter**  as its parent, it is
        deleted.

        For convenience, if **model** is a **QFileSystemModel** , **QCompleter**
        switches its **caseSensitivity**  to **Qt::CaseInsensitive**  on Windows
        and **Qt::CaseSensitive**  on other platforms.

        **See also** **completionModel** (), **modelSorting** , and **Handling
        Tree Models** .
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qcompleter.html#widget

        **QWidget *QCompleter::widget() const**

        Returns the widget for which the completer object is providing
        completions.

        **See also** **setWidget** ().
        """
        ...

    def setWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qcompleter.html#setWidget

        **void QCompleter::setWidget(QWidget * widget )**

        Sets the widget for which completion are provided for to **widget**.
        This function is automatically called when a **QCompleter**  is set on a
        **QLineEdit**  using **QLineEdit::setCompleter** () or on a
        **QComboBox**  using **QComboBox::setCompleter** (). The widget needs to
        be set explicitly when providing completions for custom widgets.

        **See also** **widget** (), **setModel** (), and **setPopup** ().
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcompleter.html#activated

        **[signal] void QCompleter::activated(const QString & text )**

        This signal is sent when an item in the **popup** () is activated by the
        user (by clicking or pressing return). The item's **text** is given.

        **Note:** Signal **activated** is overloaded in this class. To connect
        to this signal by using the function pointer syntax, Qt provides a
        convenient helper for obtaining the function pointer as shown in this
        example:

        connect(completer, QOverload<const **QString**  &>::of(&**QCompleter**
        ::activated),
                [=](const **QString**  &text){ /* ... */ });
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcompleter.html#activated-1

        **[signal] void QCompleter::activated(const QModelIndex & index )**

        This signal is sent when an item in the **popup** () is activated by the
        user. (by clicking or pressing return). The item's **index** in the
        **completionModel** () is given.

        **Note:** Signal **activated** is overloaded in this class. To connect
        to this signal by using the function pointer syntax, Qt provides a
        convenient helper for obtaining the function pointer as shown in this
        example:

        connect(completer, QOverload<const **QModelIndex**
        &>::of(&**QCompleter** ::activated),
                [=](const **QModelIndex**
        &index){ /* ... */ });
        """
        ...

    @property
    def highlighted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcompleter.html#highlighted

        **[signal] void QCompleter::highlighted(const QString & text )**

        This signal is sent when an item in the **popup** () is highlighted by
        the user. It is also sent if **complete** () is called with the
        **completionMode** () set to **QCompleter::InlineCompletion** . The
        item's **text** is given.

        **Note:** Signal **highlighted** is overloaded in this class. To connect
        to this signal by using the function pointer syntax, Qt provides a
        convenient helper for obtaining the function pointer as shown in this
        example:

        connect(completer, QOverload<const **QString**  &>::of(&**QCompleter**
        ::highlighted),
                [=](const **QString**  &text){ /* ... */ });
        """
        ...

    @property
    def highlighted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcompleter.html#highlighted-1

        **[signal] void QCompleter::highlighted(const QModelIndex & index )**

        This signal is sent when an item in the **popup** () is highlighted by
        the user. It is also sent if **complete** () is called with the
        **completionMode** () set to **QCompleter::InlineCompletion** . The
        item's **index** in the **completionModel** () is given.

        **Note:** Signal **highlighted** is overloaded in this class. To connect
        to this signal by using the function pointer syntax, Qt provides a
        convenient helper for obtaining the function pointer as shown in this
        example:

        connect(completer, QOverload<const **QModelIndex**
        &>::of(&**QCompleter** ::highlighted),
                [=](const **QModelIndex**
        &index){ /* ... */ });
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QSurface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsurface.html

    **Detailed Description**

    The size of the surface is accessible with the **size** () function. The
    rendering specific attributes of the surface are accessible through the
    **format** () function.
    """

    class SurfaceType(enum.Enum):
        RasterSurface: QSurface = ...
        OpenGLSurface: QSurface = ...
        RasterGLSurface: QSurface = ...
        OpenVGSurface: QSurface = ...
        VulkanSurface: QSurface = ...
        MetalSurface: QSurface = ...
        Direct3DSurface: QSurface = ...

    class SurfaceClass(enum.Enum):
        Window: QSurface = ...
        Offscreen: QSurface = ...

    @typing.overload
    def __init__(self, type: "QSurface.SurfaceClass") -> None:
        """
        https://doc.qt.io/qt-6/qsurface.html#QSurface

        **[protected] QSurface::QSurface(QSurface::SurfaceClass type )**

        Creates a surface with the given **type**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QSurface") -> None:
        """
        https://doc.qt.io/qt-6/qsurface.html#QSurface

        **[protected] QSurface::QSurface(QSurface::SurfaceClass type )**

        Creates a surface with the given **type**.
        """
        ...

    def supportsOpenGL(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsurface.html#supportsOpenGL

        **[since 5.3] bool QSurface::supportsOpenGL() const**

        Returns true if the surface is OpenGL compatible and can be used in
        conjunction with **QOpenGLContext** ; otherwise returns false.

        This function was introduced in Qt 5.3.
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsurface.html#size

        **[pure virtual] QSize QSurface::size() const**

        Returns the size of the surface in pixels.
        """
        ...

    def surfaceType(self) -> "QSurface.SurfaceType":
        """
        https://doc.qt.io/qt-6/qsurface.html#surfaceType

        **[pure virtual] QSurface::SurfaceType QSurface::surfaceType() const**

        Returns the type of the surface.
        """
        ...

    def format(self) -> "QSurfaceFormat":
        """
        https://doc.qt.io/qt-6/qsurface.html#format

        **[pure virtual] QSurfaceFormat QSurface::format() const**

        Returns the format of the surface.
        """
        ...

    def surfaceClass(self) -> "QSurface.SurfaceClass":
        """
        https://doc.qt.io/qt-6/qsurface.html#surfaceClass

        **QSurface::SurfaceClass QSurface::surfaceClass() const**

        Returns the surface class of this surface.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QEvent(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qevent.html

    **Detailed Description**

    Qt's main event loop (**QCoreApplication::exec** ()) fetches native window
    system events from the event queue, translates them into QEvents, and sends
    the translated events to **QObject** s.

    In general, events come from the underlying window system (**spontaneous**
    () returns `true`), but it is also possible to manually send events using
    **QCoreApplication::sendEvent** () and **QCoreApplication::postEvent** ()
    (**spontaneous** () returns `false`).

    **QObjects**  receive events by having their **QObject::event** () function
    called. The function can be reimplemented in subclasses to customize event
    handling and add additional event types; **QWidget::event** () is a notable
    example. By default, events are dispatched to event handlers like
    **QObject::timerEvent** () and **QWidget::mouseMoveEvent** ().
    **QObject::installEventFilter** () allows an object to intercept events
    destined for another object.

    The basic QEvent contains only an event type parameter and an "accept" flag.
    The accept flag set with **accept** (), and cleared with **ignore** (). It
    is set by default, but don't rely on this as subclasses may choose to clear
    it in their constructor.

    Subclasses of QEvent contain additional parameters that describe the
    particular event.

    **See also** **QObject::event** (), **QObject::installEventFilter** (),
    **QCoreApplication::sendEvent** (), **QCoreApplication::postEvent** (), and
    **QCoreApplication::processEvents** ().
    """

    class Type(enum.IntEnum):
        None_: QEvent = ...
        Timer: QEvent = ...
        MouseButtonPress: QEvent = ...
        MouseButtonRelease: QEvent = ...
        MouseButtonDblClick: QEvent = ...
        MouseMove: QEvent = ...
        KeyPress: QEvent = ...
        KeyRelease: QEvent = ...
        FocusIn: QEvent = ...
        FocusOut: QEvent = ...
        Enter: QEvent = ...
        Leave: QEvent = ...
        Paint: QEvent = ...
        Move: QEvent = ...
        Resize: QEvent = ...
        Show: QEvent = ...
        Hide: QEvent = ...
        Close: QEvent = ...
        ParentChange: QEvent = ...
        ParentAboutToChange: QEvent = ...
        ThreadChange: QEvent = ...
        WindowActivate: QEvent = ...
        WindowDeactivate: QEvent = ...
        ShowToParent: QEvent = ...
        HideToParent: QEvent = ...
        Wheel: QEvent = ...
        WindowTitleChange: QEvent = ...
        WindowIconChange: QEvent = ...
        ApplicationWindowIconChange: QEvent = ...
        ApplicationFontChange: QEvent = ...
        ApplicationLayoutDirectionChange: QEvent = ...
        ApplicationPaletteChange: QEvent = ...
        PaletteChange: QEvent = ...
        Clipboard: QEvent = ...
        MetaCall: QEvent = ...
        SockAct: QEvent = ...
        WinEventAct: QEvent = ...
        DeferredDelete: QEvent = ...
        DragEnter: QEvent = ...
        DragMove: QEvent = ...
        DragLeave: QEvent = ...
        Drop: QEvent = ...
        ChildAdded: QEvent = ...
        ChildPolished: QEvent = ...
        ChildRemoved: QEvent = ...
        PolishRequest: QEvent = ...
        Polish: QEvent = ...
        LayoutRequest: QEvent = ...
        UpdateRequest: QEvent = ...
        UpdateLater: QEvent = ...
        ContextMenu: QEvent = ...
        InputMethod: QEvent = ...
        TabletMove: QEvent = ...
        LocaleChange: QEvent = ...
        LanguageChange: QEvent = ...
        LayoutDirectionChange: QEvent = ...
        TabletPress: QEvent = ...
        TabletRelease: QEvent = ...
        OkRequest: QEvent = ...
        IconDrag: QEvent = ...
        FontChange: QEvent = ...
        EnabledChange: QEvent = ...
        ActivationChange: QEvent = ...
        StyleChange: QEvent = ...
        IconTextChange: QEvent = ...
        ModifiedChange: QEvent = ...
        MouseTrackingChange: QEvent = ...
        WindowBlocked: QEvent = ...
        WindowUnblocked: QEvent = ...
        WindowStateChange: QEvent = ...
        ToolTip: QEvent = ...
        WhatsThis: QEvent = ...
        StatusTip: QEvent = ...
        ActionChanged: QEvent = ...
        ActionAdded: QEvent = ...
        ActionRemoved: QEvent = ...
        FileOpen: QEvent = ...
        Shortcut: QEvent = ...
        ShortcutOverride: QEvent = ...
        WhatsThisClicked: QEvent = ...
        ToolBarChange: QEvent = ...
        ApplicationActivate: QEvent = ...
        ApplicationActivated: QEvent = ...
        ApplicationDeactivate: QEvent = ...
        ApplicationDeactivated: QEvent = ...
        QueryWhatsThis: QEvent = ...
        EnterWhatsThisMode: QEvent = ...
        LeaveWhatsThisMode: QEvent = ...
        ZOrderChange: QEvent = ...
        HoverEnter: QEvent = ...
        HoverLeave: QEvent = ...
        HoverMove: QEvent = ...
        GraphicsSceneMouseMove: QEvent = ...
        GraphicsSceneMousePress: QEvent = ...
        GraphicsSceneMouseRelease: QEvent = ...
        GraphicsSceneMouseDoubleClick: QEvent = ...
        GraphicsSceneContextMenu: QEvent = ...
        GraphicsSceneHoverEnter: QEvent = ...
        GraphicsSceneHoverMove: QEvent = ...
        GraphicsSceneHoverLeave: QEvent = ...
        GraphicsSceneHelp: QEvent = ...
        GraphicsSceneDragEnter: QEvent = ...
        GraphicsSceneDragMove: QEvent = ...
        GraphicsSceneDragLeave: QEvent = ...
        GraphicsSceneDrop: QEvent = ...
        GraphicsSceneWheel: QEvent = ...
        GraphicsSceneResize: QEvent = ...
        GraphicsSceneMove: QEvent = ...
        KeyboardLayoutChange: QEvent = ...
        DynamicPropertyChange: QEvent = ...
        TabletEnterProximity: QEvent = ...
        TabletLeaveProximity: QEvent = ...
        NonClientAreaMouseMove: QEvent = ...
        NonClientAreaMouseButtonPress: QEvent = ...
        NonClientAreaMouseButtonRelease: QEvent = ...
        NonClientAreaMouseButtonDblClick: QEvent = ...
        MacSizeChange: QEvent = ...
        ContentsRectChange: QEvent = ...
        CursorChange: QEvent = ...
        ToolTipChange: QEvent = ...
        GrabMouse: QEvent = ...
        UngrabMouse: QEvent = ...
        GrabKeyboard: QEvent = ...
        UngrabKeyboard: QEvent = ...
        StateMachineSignal: QEvent = ...
        StateMachineWrapped: QEvent = ...
        TouchBegin: QEvent = ...
        TouchUpdate: QEvent = ...
        TouchEnd: QEvent = ...
        RequestSoftwareInputPanel: QEvent = ...
        CloseSoftwareInputPanel: QEvent = ...
        WinIdChange: QEvent = ...
        Gesture: QEvent = ...
        GestureOverride: QEvent = ...
        FocusAboutToChange: QEvent = ...
        ScrollPrepare: QEvent = ...
        Scroll: QEvent = ...
        Expose: QEvent = ...
        InputMethodQuery: QEvent = ...
        OrientationChange: QEvent = ...
        TouchCancel: QEvent = ...
        PlatformPanel: QEvent = ...
        ApplicationStateChange: QEvent = ...
        ReadOnlyChange: QEvent = ...
        PlatformSurface: QEvent = ...
        TabletTrackingChange: QEvent = ...
        GraphicsSceneLeave: QEvent = ...
        User: QEvent = ...
        MaxUser: QEvent = ...

    @typing.overload
    def __init__(self, type: "QEvent.Type") -> None:
        """
        https://doc.qt.io/qt-6/qevent.html#QEvent-2

        **QEvent::QEvent(QEvent::Type type )**

        Constructs an event object of type **type**.
        """
        ...

    @typing.overload
    def __init__(self, type: int) -> None:
        """
        https://doc.qt.io/qt-6/qevent.html#QEvent-2

        **QEvent::QEvent(QEvent::Type type )**

        Constructs an event object of type **type**.
        """
        ...

    def clone(self) -> "QEvent":
        """
        https://doc.qt.io/qt-6/qevent.html#clone

        **[virtual, since 6.0] QEvent *QEvent::clone() const**

        Creates and returns an identical copy of this event.

        This function was introduced in Qt 6.0.
        """
        ...

    def isSinglePointEvent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qevent.html#isSinglePointEvent

        **[since 6.0] bool QEvent::isSinglePointEvent() const**

        Returns `true` if the event object is a subclass of
        **QSinglePointEvent** .

        This function was introduced in Qt 6.0.
        """
        ...

    def isPointerEvent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qevent.html#isPointerEvent

        **[since 6.0] bool QEvent::isPointerEvent() const**

        Returns `true` if the event object is a **QPointerEvent**  or one of its
        subclasses.

        This function was introduced in Qt 6.0.
        """
        ...

    def isInputEvent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qevent.html#isInputEvent

        **[since 6.0] bool QEvent::isInputEvent() const**

        Returns `true` if the event object is a **QInputEvent**  or one of its
        subclasses.

        This function was introduced in Qt 6.0.
        """
        ...

    @staticmethod
    def registerEventType(hint: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qevent.html#registerEventType

        **[static] int QEvent::registerEventType(int hint = -1)**

        Registers and returns a custom event type. The **hint** provided will be
        used if it is available, otherwise it will return a value between
        **QEvent::User**  and **QEvent::MaxUser**  that has not yet been
        registered. The **hint** is ignored if its value is not between
        **QEvent::User**  and **QEvent::MaxUser** .

        Returns -1 if all available values are already taken or the program is
        shutting down.

        **Note:** This function is **thread-safe** .
        """
        ...

    def ignore(self) -> None:
        """
        https://doc.qt.io/qt-6/qevent.html#ignore

        **void QEvent::ignore()**

        Clears the accept flag parameter of the event object, the equivalent of
        calling **setAccepted** (false).

        Clearing the accept parameter indicates that the event receiver does not
        want the event. Unwanted events might be propagated to the parent
        widget.

        **See also** **accept** ().
        """
        ...

    def accept(self) -> None:
        """
        https://doc.qt.io/qt-6/qevent.html#accept

        **void QEvent::accept()**

        Sets the accept flag of the event object, the equivalent of calling
        **setAccepted** (true).

        Setting the accept parameter indicates that the event receiver wants the
        event. Unwanted events might be propagated to the parent widget.

        **See also** **ignore** ().
        """
        ...

    def isAccepted(self) -> bool:
        ...

    def setAccepted(self, accepted: bool) -> None:
        """
        https://doc.qt.io/qt-6/qevent.html#accepted-prop

        **accepted : bool**

        This property holds the accept flag of the event object.

        Setting the accept parameter indicates that the event receiver wants the
        event. Unwanted events might be propagated to the parent widget. By
        default, isAccepted() is set to true, but don't rely on this as
        subclasses may choose to clear it in their constructor.

        For convenience, the accept flag can also be set with **accept** (), and
        cleared with **ignore** ().

        **Note:** Accepting a **QPointerEvent**  implicitly **accepts**  all the
        **points**  that the event carries.

        **Access functions:**

        bool **isAccepted** () const
        virtual void **setAccepted** (bool
        **accepted** )

        **Member Function Documentation**
        """
        ...

    def spontaneous(self) -> bool:
        """
        https://doc.qt.io/qt-6/qevent.html#spontaneous

        **bool QEvent::spontaneous() const**

        Returns `true` if the event originated outside the application (a system
        event); otherwise returns `false`.
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qevent.html#type

        **QEvent::Type QEvent::type() const**

        Returns the event type.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QChildEvent(QEvent):
    """
    https://doc.qt.io/qt-6/qchildevent.html

    **Detailed Description**

    Child events are sent immediately to objects when children are added or
    removed.

    In both cases you can only rely on the child being a **QObject**  (or, if
    **QObject::isWidgetType** () returns `true`, a **QWidget** ). This is
    because in the **QEvent::ChildAdded**  case the child is not yet fully
    constructed; in the **QEvent::ChildRemoved**  case it might have already
    been destructed.

    The handler for these events is **QObject::childEvent** ().
    """

    @typing.overload
    def __init__(self, type: QEvent.Type, child: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qchildevent.html#QChildEvent-2

        **QChildEvent::QChildEvent(QEvent::Type type , QObject * child )**

        Constructs a child event object of a particular **type** for the
        **child**.

        **type** can be **QEvent::ChildAdded** , **QEvent::ChildRemoved** , or
        **QEvent::ChildPolished** .

        **See also** **child** ().
        """
        ...

    @typing.overload
    def __init__(self, type: int, child: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qchildevent.html#QChildEvent-2

        **QChildEvent::QChildEvent(QEvent::Type type , QObject * child )**

        Constructs a child event object of a particular **type** for the
        **child**.

        **type** can be **QEvent::ChildAdded** , **QEvent::ChildRemoved** , or
        **QEvent::ChildPolished** .

        **See also** **child** ().
        """
        ...

    def clone(self) -> "QChildEvent":
        ...

    def removed(self) -> bool:
        """
        https://doc.qt.io/qt-6/qchildevent.html#removed

        **bool QChildEvent::removed() const**

        Returns `true` if **type** () is **QEvent::ChildRemoved** ; otherwise
        returns false.
        """
        ...

    def polished(self) -> bool:
        """
        https://doc.qt.io/qt-6/qchildevent.html#polished

        **bool QChildEvent::polished() const**

        Returns `true` if **type** () is **QEvent::ChildPolished** ; otherwise
        returns false.
        """
        ...

    def added(self) -> bool:
        """
        https://doc.qt.io/qt-6/qchildevent.html#added

        **bool QChildEvent::added() const**

        Returns `true` if **type** () is **QEvent::ChildAdded** ; otherwise
        returns false.
        """
        ...

    def child(self) -> QObject:
        """
        https://doc.qt.io/qt-6/qchildevent.html#child

        **QObject *QChildEvent::child() const**

        Returns the child object that was added or removed.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._functions import PYQT_VERSION as PYQT_VERSION
from ._functions import PYQT_VERSION_STR as PYQT_VERSION_STR
from ._functions import QT_VERSION as QT_VERSION
from ._functions import QT_VERSION_STR as QT_VERSION_STR
from ._functions import qSetRealNumberPrecision as qSetRealNumberPrecision
from ._functions import qSetPadChar as qSetPadChar
from ._functions import qSetFieldWidth as qSetFieldWidth
from ._functions import Q_RETURN_ARG as Q_RETURN_ARG
from ._functions import Q_ARG as Q_ARG
from ._functions import QT_TRANSLATE_NOOP as QT_TRANSLATE_NOOP
from ._functions import QT_TR_NOOP as QT_TR_NOOP
from ._functions import pyqtSlot as pyqtSlot
from ._functions import pyqtEnum as pyqtEnum
from ._functions import pyqtClassInfo as pyqtClassInfo
from ._functions import qFloatDistance as qFloatDistance
from ._functions import qQNaN as qQNaN
from ._functions import qSNaN as qSNaN
from ._functions import qInf as qInf
from ._functions import qIsNaN as qIsNaN
from ._functions import qIsFinite as qIsFinite
from ._functions import qIsInf as qIsInf
from ._functions import qFormatLogMessage as qFormatLogMessage
from ._functions import qSetMessagePattern as qSetMessagePattern
from ._functions import qInstallMessageHandler as qInstallMessageHandler
from ._functions import qWarning as qWarning
from ._functions import qInfo as qInfo
from ._functions import qFatal as qFatal
from ._functions import qDebug as qDebug
from ._functions import qCritical as qCritical
from ._functions import pyqtRestoreInputHook as pyqtRestoreInputHook
from ._functions import pyqtRemoveInputHook as pyqtRemoveInputHook
from ._functions import qAddPreRoutine as qAddPreRoutine
from ._functions import qRemovePostRoutine as qRemovePostRoutine
from ._functions import qAddPostRoutine as qAddPostRoutine
from ._functions import qChecksum as qChecksum
from ._functions import qUncompress as qUncompress
from ._functions import qUncompress as qUncompress
from ._functions import qCompress as qCompress
from ._functions import qCompress as qCompress
from ._functions import qEnvironmentVariableIntValue as qEnvironmentVariableIntValue
from ._functions import qEnvironmentVariable as qEnvironmentVariable
from ._functions import qEnvironmentVariable as qEnvironmentVariable
from ._functions import qEnvironmentVariableIsSet as qEnvironmentVariableIsSet
from ._functions import qEnvironmentVariableIsEmpty as qEnvironmentVariableIsEmpty
from ._functions import pyqtPickleProtocol as pyqtPickleProtocol
from ._functions import pyqtSetPickleProtocol as pyqtSetPickleProtocol
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qVersion as qVersion
from ._functions import qRound64 as qRound64
from ._functions import qRound as qRound
from ._functions import qAbs as qAbs
from ._pyqtSignal import pyqtSignal as pyqtSignal
from ._pyqtBoundSignal import pyqtBoundSignal as pyqtBoundSignal
from ._QtMsgType import QtMsgType as QtMsgType
from ._QCborKnownTags import QCborKnownTags as QCborKnownTags
from ._QCborSimpleType import QCborSimpleType as QCborSimpleType
from ._Qt import Qt as Qt
from ._QKeyCombination import QKeyCombination as QKeyCombination
from ._QObject import QObject as QObject
from ._QAbstractAnimation import QAbstractAnimation as QAbstractAnimation
from ._QAbstractEventDispatcher import (
    QAbstractEventDispatcher as QAbstractEventDispatcher,
)
from ._QModelIndex import QModelIndex as QModelIndex
from ._QPersistentModelIndex import QPersistentModelIndex as QPersistentModelIndex
from ._QAbstractItemModel import QAbstractItemModel as QAbstractItemModel
from ._QAbstractTableModel import QAbstractTableModel as QAbstractTableModel
from ._QAbstractListModel import QAbstractListModel as QAbstractListModel
from ._QModelRoleData import QModelRoleData as QModelRoleData
from ._QAbstractNativeEventFilter import (
    QAbstractNativeEventFilter as QAbstractNativeEventFilter,
)
from ._QAbstractProxyModel import QAbstractProxyModel as QAbstractProxyModel
from ._QAnimationGroup import QAnimationGroup as QAnimationGroup
from ._QBasicTimer import QBasicTimer as QBasicTimer
from ._QBitArray import QBitArray as QBitArray
from ._QIODeviceBase import QIODeviceBase as QIODeviceBase
from ._QIODevice import QIODevice as QIODevice
from ._QBuffer import QBuffer as QBuffer
from ._QByteArray import QByteArray as QByteArray
from ._QByteArrayMatcher import QByteArrayMatcher as QByteArrayMatcher
from ._QCalendar import QCalendar as QCalendar
from ._QCborError import QCborError as QCborError
from ._QCborStreamReader import QCborStreamReader as QCborStreamReader
from ._QCborStreamWriter import QCborStreamWriter as QCborStreamWriter
from ._QCollatorSortKey import QCollatorSortKey as QCollatorSortKey
from ._QCollator import QCollator as QCollator
from ._QCommandLineOption import QCommandLineOption as QCommandLineOption
from ._QCommandLineParser import QCommandLineParser as QCommandLineParser
from ._QConcatenateTablesProxyModel import (
    QConcatenateTablesProxyModel as QConcatenateTablesProxyModel,
)
from ._QCoreApplication import QCoreApplication as QCoreApplication
from ._QEvent import QEvent as QEvent
from ._QTimerEvent import QTimerEvent as QTimerEvent
from ._QChildEvent import QChildEvent as QChildEvent
from ._QDynamicPropertyChangeEvent import (
    QDynamicPropertyChangeEvent as QDynamicPropertyChangeEvent,
)
from ._QCryptographicHash import QCryptographicHash as QCryptographicHash
from ._QDataStream import QDataStream as QDataStream
from ._QDate import QDate as QDate
from ._QTime import QTime as QTime
from ._QDateTime import QDateTime as QDateTime
from ._QDeadlineTimer import QDeadlineTimer as QDeadlineTimer
from ._QDir import QDir as QDir
from ._QDirIterator import QDirIterator as QDirIterator
from ._QEasingCurve import QEasingCurve as QEasingCurve
from ._QElapsedTimer import QElapsedTimer as QElapsedTimer
from ._QEventLoop import QEventLoop as QEventLoop
from ._QEventLoopLocker import QEventLoopLocker as QEventLoopLocker
from ._QFileDevice import QFileDevice as QFileDevice
from ._QFile import QFile as QFile
from ._QFileInfo import QFileInfo as QFileInfo
from ._QFileSelector import QFileSelector as QFileSelector
from ._QFileSystemWatcher import QFileSystemWatcher as QFileSystemWatcher
from ._QIdentityProxyModel import QIdentityProxyModel as QIdentityProxyModel
from ._QItemSelectionRange import QItemSelectionRange as QItemSelectionRange
from ._QItemSelectionModel import QItemSelectionModel as QItemSelectionModel
from ._QItemSelection import QItemSelection as QItemSelection
from ._QJsonParseError import QJsonParseError as QJsonParseError
from ._QJsonDocument import QJsonDocument as QJsonDocument
from ._QJsonValue import QJsonValue as QJsonValue
from ._QLibrary import QLibrary as QLibrary
from ._QLibraryInfo import QLibraryInfo as QLibraryInfo
from ._QLine import QLine as QLine
from ._QLineF import QLineF as QLineF
from ._QLocale import QLocale as QLocale
from ._QLockFile import QLockFile as QLockFile
from ._QMessageLogContext import QMessageLogContext as QMessageLogContext
from ._QMessageLogger import QMessageLogger as QMessageLogger
from ._QLoggingCategory import QLoggingCategory as QLoggingCategory
from ._QMargins import QMargins as QMargins
from ._QMarginsF import QMarginsF as QMarginsF
from ._QMessageAuthenticationCode import (
    QMessageAuthenticationCode as QMessageAuthenticationCode,
)
from ._QMetaMethod import QMetaMethod as QMetaMethod
from ._QMetaEnum import QMetaEnum as QMetaEnum
from ._QMetaProperty import QMetaProperty as QMetaProperty
from ._QMetaClassInfo import QMetaClassInfo as QMetaClassInfo
from ._QMetaType import QMetaType as QMetaType
from ._QMimeData import QMimeData as QMimeData
from ._QMimeDatabase import QMimeDatabase as QMimeDatabase
from ._QMimeType import QMimeType as QMimeType
from ._QMutex import QMutex as QMutex
from ._QRecursiveMutex import QRecursiveMutex as QRecursiveMutex
from ._QSignalBlocker import QSignalBlocker as QSignalBlocker
from ._QObjectCleanupHandler import QObjectCleanupHandler as QObjectCleanupHandler
from ._QMetaObject import QMetaObject as QMetaObject
from ._QGenericArgument import QGenericArgument as QGenericArgument
from ._QGenericReturnArgument import QGenericReturnArgument as QGenericReturnArgument
from ._QOperatingSystemVersion import QOperatingSystemVersion as QOperatingSystemVersion
from ._QParallelAnimationGroup import QParallelAnimationGroup as QParallelAnimationGroup
from ._QPauseAnimation import QPauseAnimation as QPauseAnimation
from ._QVariantAnimation import QVariantAnimation as QVariantAnimation
from ._QPropertyAnimation import QPropertyAnimation as QPropertyAnimation
from ._QPluginLoader import QPluginLoader as QPluginLoader
from ._QPoint import QPoint as QPoint
from ._QPointF import QPointF as QPointF
from ._QProcess import QProcess as QProcess
from ._QProcessEnvironment import QProcessEnvironment as QProcessEnvironment
from ._QRandomGenerator import QRandomGenerator as QRandomGenerator
from ._QReadWriteLock import QReadWriteLock as QReadWriteLock
from ._QReadLocker import QReadLocker as QReadLocker
from ._QWriteLocker import QWriteLocker as QWriteLocker
from ._QRect import QRect as QRect
from ._QRectF import QRectF as QRectF
from ._QRegularExpression import QRegularExpression as QRegularExpression
from ._QRegularExpressionMatch import QRegularExpressionMatch as QRegularExpressionMatch
from ._QRegularExpressionMatchIterator import (
    QRegularExpressionMatchIterator as QRegularExpressionMatchIterator,
)
from ._QResource import QResource as QResource
from ._QRunnable import QRunnable as QRunnable
from ._QSaveFile import QSaveFile as QSaveFile
from ._QSemaphore import QSemaphore as QSemaphore
from ._QSemaphoreReleaser import QSemaphoreReleaser as QSemaphoreReleaser
from ._QSequentialAnimationGroup import (
    QSequentialAnimationGroup as QSequentialAnimationGroup,
)
from ._QSettings import QSettings as QSettings
from ._QSharedMemory import QSharedMemory as QSharedMemory
from ._QSignalMapper import QSignalMapper as QSignalMapper
from ._QSize import QSize as QSize
from ._QSizeF import QSizeF as QSizeF
from ._QSocketNotifier import QSocketNotifier as QSocketNotifier
from ._QSortFilterProxyModel import QSortFilterProxyModel as QSortFilterProxyModel
from ._QStandardPaths import QStandardPaths as QStandardPaths
from ._QStorageInfo import QStorageInfo as QStorageInfo
from ._QStringConverterBase import QStringConverterBase as QStringConverterBase
from ._QStringConverter import QStringConverter as QStringConverter
from ._QStringEncoder import QStringEncoder as QStringEncoder
from ._QStringDecoder import QStringDecoder as QStringDecoder
from ._QStringListModel import QStringListModel as QStringListModel
from ._QSysInfo import QSysInfo as QSysInfo
from ._QSystemSemaphore import QSystemSemaphore as QSystemSemaphore
from ._QTemporaryDir import QTemporaryDir as QTemporaryDir
from ._QTemporaryFile import QTemporaryFile as QTemporaryFile
from ._QTextBoundaryFinder import QTextBoundaryFinder as QTextBoundaryFinder
from ._QTextStream import QTextStream as QTextStream
from ._QTextStreamManipulator import QTextStreamManipulator as QTextStreamManipulator
from ._QThread import QThread as QThread
from ._QThreadPool import QThreadPool as QThreadPool
from ._QTimeLine import QTimeLine as QTimeLine
from ._QTimer import QTimer as QTimer
from ._QTimeZone import QTimeZone as QTimeZone
from ._QTranslator import QTranslator as QTranslator
from ._QTransposeProxyModel import QTransposeProxyModel as QTransposeProxyModel
from ._QUrl import QUrl as QUrl
from ._QUrlQuery import QUrlQuery as QUrlQuery
from ._QUuid import QUuid as QUuid
from ._QVariant import QVariant as QVariant
from ._QVersionNumber import QVersionNumber as QVersionNumber
from ._QTypeRevision import QTypeRevision as QTypeRevision
from ._QWaitCondition import QWaitCondition as QWaitCondition
from ._QXmlStreamAttribute import QXmlStreamAttribute as QXmlStreamAttribute
from ._QXmlStreamNamespaceDeclaration import (
    QXmlStreamNamespaceDeclaration as QXmlStreamNamespaceDeclaration,
)
from ._QXmlStreamNotationDeclaration import (
    QXmlStreamNotationDeclaration as QXmlStreamNotationDeclaration,
)
from ._QXmlStreamEntityDeclaration import (
    QXmlStreamEntityDeclaration as QXmlStreamEntityDeclaration,
)
from ._QXmlStreamEntityResolver import (
    QXmlStreamEntityResolver as QXmlStreamEntityResolver,
)
from ._QXmlStreamReader import QXmlStreamReader as QXmlStreamReader
from ._QXmlStreamWriter import QXmlStreamWriter as QXmlStreamWriter
from ._QXmlStreamAttributes import QXmlStreamAttributes as QXmlStreamAttributes
from ._QMutexLocker import QMutexLocker as QMutexLocker
from ._QWinEventNotifier import QWinEventNotifier as QWinEventNotifier



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QMutexLocker(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmutexlocker.html

    **Detailed Description**

    Locking and unlocking a **QMutex**  or **QRecursiveMutex**  in complex
    functions and statements or in exception handling code is error-prone and
    difficult to debug. QMutexLocker can be used in such situations to ensure
    that the state of the mutex is always well-defined.

    QMutexLocker should be created within a function where a **QMutex**  needs
    to be locked. The mutex is locked when QMutexLocker is created. You can
    unlock and relock the mutex with `unlock()` and `relock()`. If locked, the
    mutex will be unlocked when the QMutexLocker is destroyed.

    For example, this complex function locks a **QMutex**  upon entering the
    function and unlocks the mutex at all the exit points:

    int complexFunction(int flag)
        {
            mutex.lock();

            int
    retVal = 0;

            switch (flag) {
            case 0:
            case 1:
    retVal = moreComplexFunction(flag);
                break;
            case 2:
    {
                    int status = anotherFunction();
                    if (status
    < 0) {
                        mutex.unlock();
                        return -2;
    }
                    retVal = status + flag;
                }
                break;
    default:
                if (flag > 10) {
                    mutex.unlock();
    return -1;
                }
                break;
            }
    mutex.unlock();
            return retVal;
        }

    This example function will get more complicated as it is developed, which
    increases the likelihood that errors will occur.

    Using QMutexLocker greatly simplifies the code, and makes it more readable:

    int complexFunction(int flag)
        {
            **QMutexLocker**
    locker(&mutex);

            int retVal = 0;

            switch (flag) {
    case 0:
            case 1:
                return moreComplexFunction(flag);
    case 2:
                {
                    int status = anotherFunction();
    if (status < 0)
                        return -2;
                    retVal =
    status + flag;
                }
                break;
            default:
    if (flag > 10)
                    return -1;
                break;
            }
    return retVal;
        }

    Now, the mutex will always be unlocked when the QMutexLocker object is
    destroyed (when the function returns since `locker` is an auto variable).

    The same principle applies to code that throws and catches exceptions. An
    exception that is not caught in the function that has locked the mutex has
    no way of unlocking the mutex before the exception is passed up the stack to
    the calling function.

    QMutexLocker also provides a `mutex()` member function that returns the
    mutex on which the QMutexLocker is operating. This is useful for code that
    needs access to the mutex, such as **QWaitCondition::wait** (). For example:

    class SignalWaiter
        {
        private:
            **QMutexLocker** <**QMutex** >
    locker;

        public:
            SignalWaiter(**QMutex**  *mutex)
    : locker(mutex)
            {
            }

            void waitForSignal()
    {
                ...
                while (!signalled)
    waitCondition.wait(locker.mutex());
                ...
            }
        };

    **See also** **QReadLocker** , **QWriteLocker** , and **QMutex** .
    """

    @typing.overload
    def __init__(self, mutex: QMutex) -> None:
        """
        https://doc.qt.io/qt-6/qmutexlocker.html#QMutexLocker

        **QMutexLocker::QMutexLocker(Mutex * mutex )**

        Constructs a QMutexLocker and locks **mutex**. The mutex will be
        unlocked when the QMutexLocker is destroyed. If **mutex** is `nullptr`,
        QMutexLocker does nothing.

        **See also** **QMutex::lock** ().
        """
        ...

    @typing.overload
    def __init__(self, mutex: QRecursiveMutex) -> None:
        """
        https://doc.qt.io/qt-6/qmutexlocker.html#QMutexLocker

        **QMutexLocker::QMutexLocker(Mutex * mutex )**

        Constructs a QMutexLocker and locks **mutex**. The mutex will be
        unlocked when the QMutexLocker is destroyed. If **mutex** is `nullptr`,
        QMutexLocker does nothing.

        **See also** **QMutex::lock** ().
        """
        ...

    def __exit__(
        self, type: typing.Any, value: typing.Any, traceback: typing.Any
    ) -> None:
        ...

    def __enter__(self) -> typing.Any:
        ...

    def relock(self) -> None:
        """
        https://doc.qt.io/qt-6/qmutexlocker.html#relock

        **void QMutexLocker::relock()**

        Relocks an unlocked mutex locker.

        **See also** **unlock** ().
        """
        ...

    def unlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qmutexlocker.html#unlock

        **void QMutexLocker::unlock()**

        Unlocks this mutex locker. You can use `relock()` to lock it again. It
        does not need to be locked when destroyed.

        **See also** **relock** ().
        """
        ...

    def mutex(self) -> typing.Union[QMutex, QRecursiveMutex]:
        """
        https://doc.qt.io/qt-6/qmutexlocker.html#mutex

        **Mutex *QMutexLocker::mutex() const**

        Returns the mutex on which the **QMutexLocker**  is operating.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtPositioning import *
import enum


class QNmeaPositionInfoSource(QGeoPositionInfoSource):
    """
    https://doc.qt.io/qt-6/qnmeapositioninfosource.html

    **Detailed Description**

    NMEA is a commonly used protocol for the specification of one's global
    position at a certain point in time. The QNmeaPositionInfoSource class reads
    NMEA data and uses it to provide positional data in the form of
    **QGeoPositionInfo**  objects.

    A QNmeaPositionInfoSource instance operates in either **RealTimeMode**  or
    **SimulationMode** . These modes allow NMEA data to be read from either a
    live source of positional data, or replayed for simulation purposes from
    previously recorded NMEA data.

    The source of NMEA data is set with **setDevice** ().

    Use **startUpdates** () to start receiving regular position updates and
    **stopUpdates** () to stop these updates. If you only require updates
    occasionally, you can call **requestUpdate** () to request a single update.

    In both cases the position information is received via the
    **positionUpdated** () signal and the last known position can be accessed
    with **lastKnownPosition** ().

    QNmeaPositionInfoSource supports reporting the accuracy of the horizontal
    and vertical position. To enable position accuracy reporting an estimate of
    the User Equivalent Range Error associated with the NMEA source must be set
    with **setUserEquivalentRangeError** ().
    """

    class UpdateMode(enum.Enum):
        RealTimeMode: QNmeaPositionInfoSource = ...
        SimulationMode: QNmeaPositionInfoSource = ...

    def __init__(
        self,
        updateMode: "QNmeaPositionInfoSource.UpdateMode",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#QNmeaPositionInfoSou
        rce

        **QNmeaPositionInfoSource::QNmeaPositionInfoSource(QNmeaPositionInfoSour
        ce::UpdateMode updateMode , QObject * parent = nullptr)**

        Constructs a QNmeaPositionInfoSource instance with the given **parent**
        and **updateMode**.
        """
        ...

    def userEquivalentRangeError(self) -> float:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#userEquivalentRangeE
        rror

        **[since 5.3] double QNmeaPositionInfoSource::userEquivalentRangeError()
        const**

        Returns the current User Equivalent Range Error (UERE). The UERE is used
        in calculating an estimate of the accuracy of the position information
        reported by the position info source. The default value is NaN which
        means no accuracy information will be provided.

        This function was introduced in Qt 5.3.

        **See also** **setUserEquivalentRangeError** ().
        """
        ...

    def setUserEquivalentRangeError(self, uere: float) -> None:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#setUserEquivalentRan
        geError

        **[since 5.3] void
        QNmeaPositionInfoSource::setUserEquivalentRangeError(double uere )**

        Sets the User Equivalent Range Error (UERE) to **uere**. The UERE is
        used in calculating an estimate of the accuracy of the position
        information reported by the position info source. The UERE should be set
        to a value appropriate for the GPS device which generated the NMEA
        stream.

        The true UERE value is calculated from multiple error sources including
        errors introduced by the satellites and signal propogation delays
        through the atmosphere as well as errors introduced by the receiving GPS
        equipment. For details on GPS accuracy see **Sam J. Wormley, GPS Errors
        & Estimating Your Reveiver's Accuracy** .

        A typical value for UERE is approximately 5.1.

        This function was introduced in Qt 5.3.

        **See also** **userEquivalentRangeError** ().
        """
        ...

    def parsePosInfoFromNmeaData(
        self, data: bytes, size: int, posInfo: QGeoPositionInfo
    ) -> typing.Tuple[bool, bool]:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#parsePosInfoFromNmea
        Data

        **[virtual protected] bool
        QNmeaPositionInfoSource::parsePosInfoFromNmeaData(const char * data ,
        int size , QGeoPositionInfo * posInfo , bool * hasFix )**

        Parses an NMEA sentence string into a **QGeoPositionInfo** .

        The default implementation will parse standard NMEA sentences. This
        method should be reimplemented in a subclass whenever the need to deal
        with non-standard NMEA sentences arises.

        The parser reads **size** bytes from **data** and uses that information
        to setup **posInfo** and **hasFix**. If **hasFix** is set to false then
        **posInfo** may contain only the time or the date and the time.

        Returns true if the sentence was successfully parsed, otherwise returns
        false and should not modifiy **posInfo** or **hasFix**.
        """
        ...

    def requestUpdate(self, timeout: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#requestUpdate

        **[override virtual slot] void
        QNmeaPositionInfoSource::requestUpdate(int msec = 0)**

        Reimplements: **QGeoPositionInfoSource::requestUpdate** (int timeout).
        """
        ...

    def stopUpdates(self) -> None:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#stopUpdates

        **[override virtual slot] void QNmeaPositionInfoSource::stopUpdates()**

        Reimplements: **QGeoPositionInfoSource::stopUpdates** ().
        """
        ...

    def startUpdates(self) -> None:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#startUpdates

        **[override virtual slot] void QNmeaPositionInfoSource::startUpdates()**

        Reimplements: **QGeoPositionInfoSource::startUpdates** ().
        """
        ...

    def error(self) -> QGeoPositionInfoSource.Error:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#error

        **[override virtual] QGeoPositionInfoSource::Error
        QNmeaPositionInfoSource::error() const**

        Reimplements: **QGeoPositionInfoSource::error() const** .
        """
        ...

    def minimumUpdateInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#minimumUpdateInterva
        l

        **[override virtual] int
        QNmeaPositionInfoSource::minimumUpdateInterval() const**

        Reimplements an access function for property:
        **QGeoPositionInfoSource::minimumUpdateInterval** .
        """
        ...

    def supportedPositioningMethods(self) -> QGeoPositionInfoSource.PositioningMethod:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#supportedPositioning
        Methods

        **[override virtual] QGeoPositionInfoSource::PositioningMethods
        QNmeaPositionInfoSource::supportedPositioningMethods() const**

        Reimplements: **QGeoPositionInfoSource::supportedPositioningMethods()
        const** .
        """
        ...

    def lastKnownPosition(
        self, fromSatellitePositioningMethodsOnly: bool = ...
    ) -> QGeoPositionInfo:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#lastKnownPosition

        **[override virtual] QGeoPositionInfo
        QNmeaPositionInfoSource::lastKnownPosition(bool
        fromSatellitePositioningMethodsOnly = false) const**

        Reimplements: **QGeoPositionInfoSource::lastKnownPosition(bool
        fromSatellitePositioningMethodsOnly) const** .
        """
        ...

    def setUpdateInterval(self, msec: int) -> None:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#setUpdateInterval

        **[override virtual] void QNmeaPositionInfoSource::setUpdateInterval(int
        msec )**

        Reimplements an access function for property:
        **QGeoPositionInfoSource::updateInterval** .
        """
        ...

    def device(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#device

        **QIODevice *QNmeaPositionInfoSource::device() const**

        Returns the NMEA data source.

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, source: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#setDevice

        **void QNmeaPositionInfoSource::setDevice(QIODevice * device )**

        Sets the NMEA data source to **device**. If the device is not open, it
        will be opened in QIODevice::ReadOnly mode.

        The source device can only be set once and must be set before calling
        **startUpdates** () or **requestUpdate** ().

        **Note:** The **device** must emit **QIODevice::readyRead** () for the
        source to be notified when data is available for reading.
        **QNmeaPositionInfoSource**  does not assume the ownership of the
        device, and hence does not deallocate it upon destruction.

        **See also** **device** ().
        """
        ...

    def updateMode(self) -> "QNmeaPositionInfoSource.UpdateMode":
        """
        https://doc.qt.io/qt-6/qnmeapositioninfosource.html#updateMode

        **QNmeaPositionInfoSource::UpdateMode
        QNmeaPositionInfoSource::updateMode() const**

        Returns the update mode.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QSwipeGesture(QGesture):
    """
    https://doc.qt.io/qt-6/qswipegesture.html

    **Detailed Description**

    ![](images/swipegesture.png)

    For an overview of gesture handling in Qt and information on using gestures
    in your applications, see the **Gestures in Widgets and Graphics View**
    document.

    **See also** **QPanGesture**  and **QPinchGesture** .
    """

    class SwipeDirection(enum.Enum):
        NoDirection: QSwipeGesture = ...
        Left: QSwipeGesture = ...
        Right: QSwipeGesture = ...
        Up: QSwipeGesture = ...
        Down: QSwipeGesture = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        ...

    def setSwipeAngle(self, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qswipegesture.html#swipeAngle-prop

        **swipeAngle : qreal**

        This property holds the angle of the motion associated with the gesture

        If the gesture has either a horizontal or vertical component, the swipe
        angle describes the angle between the direction of motion and the x-axis
        as defined using the standard widget **coordinate system** .

        **Access functions:**

        qreal **swipeAngle** () const
        void **setSwipeAngle** (qreal **value**
        )

        **See also** **horizontalDirection**  and **verticalDirection** .
        """
        ...

    def swipeAngle(self) -> float:
        """
        https://doc.qt.io/qt-6/qswipegesture.html#swipeAngle-prop

        **swipeAngle : qreal**

        This property holds the angle of the motion associated with the gesture

        If the gesture has either a horizontal or vertical component, the swipe
        angle describes the angle between the direction of motion and the x-axis
        as defined using the standard widget **coordinate system** .

        **Access functions:**

        qreal **swipeAngle** () const
        void **setSwipeAngle** (qreal **value**
        )

        **See also** **horizontalDirection**  and **verticalDirection** .
        """
        ...

    def verticalDirection(self) -> "QSwipeGesture.SwipeDirection":
        """
        https://doc.qt.io/qt-6/qswipegesture.html#verticalDirection-prop

        **[read-only] verticalDirection : const SwipeDirection**

        This property holds the vertical direction of the gesture

        If the gesture has a vertical component, the vertical direction is
        either Up or Down; otherwise, it is **NoDirection** .

        **Access functions:**

        QSwipeGesture::SwipeDirection **verticalDirection** () const

        **See also** **horizontalDirection**  and **swipeAngle** .

        **Member Function Documentation**
        """
        ...

    def horizontalDirection(self) -> "QSwipeGesture.SwipeDirection":
        """
        https://doc.qt.io/qt-6/qswipegesture.html#horizontalDirection-prop

        **[read-only] horizontalDirection : const SwipeDirection**

        This property holds the horizontal direction of the gesture

        If the gesture has a horizontal component, the horizontal direction is
        either Left or Right; otherwise, it is **NoDirection** .

        **Access functions:**

        QSwipeGesture::SwipeDirection **horizontalDirection** () const

        **See also** **verticalDirection**  and **swipeAngle** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QAccelerometerReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qaccelerometerreading.html

    **Detailed Description**

    **QAccelerometerReading Units**

    The scale of the values is meters per second squared. The axes are arranged
    as follows.

    ![](images/sensors-coordinates2.jpg)

    A monoblock device sitting at rest, face up on a desk will experience a
    force of approximately 9.8 on the Z axis (ie. towards the roof). This is the
    proper acceleration the device experiences relative to freefall.
    """

    def setZ(self, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qaccelerometerreading.html#setZ

        **void QAccelerometerReading::setZ(qreal z )**

        Sets the acceleration on the Z axis to **z**.

        **See also** **z** ().
        """
        ...

    def z(self) -> float:
        """
        https://doc.qt.io/qt-6/qaccelerometerreading.html#z-prop

        **[read-only] z : const qreal**

        This property holds the acceleration on the Z axis.

        The scale of the values is meters per second squared.

        **Access functions:**

        qreal **z** () const

        **See also** **QAccelerometerReading Units** .

        **Member Function Documentation**
        """
        ...

    def setY(self, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qaccelerometerreading.html#setY

        **void QAccelerometerReading::setY(qreal y )**

        Sets the acceleration on the Y axis to **y**.

        **See also** **y** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qaccelerometerreading.html#y-prop

        **[read-only] y : const qreal**

        This property holds the acceleration on the Y axis.

        The scale of the values is meters per second squared.

        **Access functions:**

        qreal **y** () const

        **See also** **QAccelerometerReading Units** .
        """
        ...

    def setX(self, x: float) -> None:
        """
        https://doc.qt.io/qt-6/qaccelerometerreading.html#setX

        **void QAccelerometerReading::setX(qreal x )**

        Sets the acceleration on the X axis to **x**.

        **See also** **x** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qaccelerometerreading.html#x-prop

        **[read-only] x : const qreal**

        This property holds the acceleration on the X axis.

        The scale of the values is meters per second squared.

        **Access functions:**

        qreal **x** () const

        **See also** **QAccelerometerReading Units** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QNetworkDatagram(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnetworkdatagram.html

    **Detailed Description**

    QNetworkDatagram can be used with the **QUdpSocket**  class to represent the
    full information contained in a UDP (User Datagram Protocol) datagram.
    QNetworkDatagram encapsulates the following information of a datagram:

    * the payload data;
      * the sender address and port number;
      * the
    destination address and port number;
      * the remaining hop count limit (on
    IPv4, this field is usually called "time to live" - TTL);
      * the network
    interface index the datagram was received on or to be sent on.

    **QUdpSocket**  will try to match a common behavior as much as possible on
    all operating systems, but not all of the metadata above can be obtained in
    some operating systems. Metadata that cannot be set on the datagram when
    sending with **QUdpSocket::writeDatagram** () will be silently discarded.

    Upon reception, the **senderAddress** () and **senderPort** () properties
    contain the address and port of the peer that sent the datagram, while
    **destinationAddress** () and **destinationPort** () contain the target that
    was contained in the datagram. That is usually an address local to the
    current machine, but it can also be an IPv4 broadcast address (such as
    "255.255.255.255") or an IPv4 or IPv6 multicast address. Applications may
    find it useful to determine if the datagram was sent specifically to this
    machine via unicast addressing or whether it was sent to multiple
    destinations.

    When sending, the **senderAddress** () and **senderPort** () should contain
    the local address to be used when sending. The sender address must be an
    address that is assigned to this machine, which can be obtained using
    **QNetworkInterface** , and the port number must be the port number that the
    socket is bound to. Either field can be left unset and will be filled in by
    the operating system with default values. The **destinationAddress** () and
    **destinationPort** () fields may be set to a target address different from
    the one the UDP socket is currently associated with.

    Usually, when sending a datagram in reply to a datagram previously received,
    one will set the **destinationAddress** () to be the **senderAddress** () of
    the incoming datagram and similarly for the port numbers. To facilitate this
    common process, QNetworkDatagram provides the function **makeReply** ().

    The hopCount() function contains, for a received datagram, the remaining hop
    count limit for the packet. When sending, it contains the hop count limit to
    be set. Most protocols will leave this value set to the default and let the
    operating system decide on the best value to be used. Multicasting over IPv4
    often uses this field to indicate the scope of the multicast group (link-
    local, local to an organization or global).

    The **interfaceIndex** () function contains the index of the operating
    system's interface that received the packet. This value is the same one that
    can be set on a **QHostAddress::scopeId** () property and matches the
    **QNetworkInterface::index** () property. When sending packets to global
    addresses, it is not necessary to set the interface index as the operating
    system will choose the correct one using the system routing table. This
    property is important when sending datagrams to link-local destinations,
    whether unicast or multicast.

    **Feature support**

    Some features of QNetworkDatagram are not supported in all operating
    systems. Only the address and ports of the remote host (sender in received
    packets and destination for outgoing packets) are supported in all systems.
    On most operating systems, the other features are supported only for IPv6.
    Software should check at runtime whether the rest could be determined for
    IPv4 addresses.

    The current feature support is as follows:

    Operating systemLocal addressHop countInterface index
    FreeBSDSupportedSupportedOnly for IPv6
    LinuxSupportedSupportedSupported
    OS XSupportedSupportedOnly for IPv6
    Other Unix supporting RFC 3542Only for
    IPv6Only for IPv6Only for IPv6
    Windows
    (desktop)SupportedSupportedSupported
    Windows RTNot supportedNot
    supportedNot supported

    **See also** **QUdpSocket**  and **QNetworkInterface** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#QNetworkDatagram

        **QNetworkDatagram::QNetworkDatagram()**

        Creates a QNetworkDatagram object with no payload data and undefined
        destination address.

        The payload can be modified by using **setData** () and the destination
        address can be set with **setDestination** ().

        If the destination address is left undefined,
        **QUdpSocket::writeDatagram** () will attempt to send the datagram to
        the address last associated with, by using **QUdpSocket::connectToHost**
        ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        data: QtCore.QByteArray,
        destinationAddress: typing.Union[
            QHostAddress, QHostAddress.SpecialAddress
        ] = ...,
        port: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#QNetworkDatagram-1

        **QNetworkDatagram::QNetworkDatagram(const QByteArray & data , const
        QHostAddress & destinationAddress = QHostAddress(), quint16 port = 0)**

        Creates a QNetworkDatagram object and sets **data** as the payload data,
        along with **destinationAddress** and **port** as the destination
        address of the datagram.
        """
        ...

    @typing.overload
    def __init__(self, other: "QNetworkDatagram") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#QNetworkDatagram-2

        **QNetworkDatagram::QNetworkDatagram(const QNetworkDatagram & other )**

        Creates a copy of the **other** datagram, including the payload and
        metadata.

        To create a datagram suitable for sending in a reply, use
        **QNetworkDatagram::makeReply** ();
        """
        ...

    def makeReply(self, payload: QtCore.QByteArray) -> "QNetworkDatagram":
        ...

    def setData(self, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#setData

        **void QNetworkDatagram::setData(const QByteArray & data )**

        Sets the data payload of this datagram to **data**. It is usually not
        necessary to call this function on received datagrams. For outgoing
        datagrams, this function sets the data to be sent on the network.

        Since datagrams can empty, an empty **QByteArray**  is a valid value for
        **data**.

        **See also** **data** ().
        """
        ...

    def data(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#data

        **QByteArray QNetworkDatagram::data() const**

        Returns the data payload of this datagram. For a datagram received from
        the network, it contains the payload of the datagram. For an outgoing
        datagram, it is the datagram to be sent.

        Note that datagrams can be transmitted with no data, so the returned
        **QByteArray**  may be empty.

        **See also** **setData** ().
        """
        ...

    def setHopLimit(self, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#setHopLimit

        **void QNetworkDatagram::setHopLimit(int count )**

        Sets the hop count limit associated with this datagram to **count**. The
        hop count limit is the number of nodes that are allowed to forward the
        IP packet before it expires and an error is sent back to the sender of
        the datagram. In IPv4, this value is usually known as "time to live"
        (TTL).

        It is usually not necessary to call this function on datagrams received
        from the network.

        If this is an outgoing packet, this is the value to be set in the IP
        header upon sending. The valid range for the value is 1 to 255. This
        function also accepts a value of -1 to indicate that the operating
        system should choose the value.

        **See also** **hopLimit** ().
        """
        ...

    def hopLimit(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#hopLimit

        **int QNetworkDatagram::hopLimit() const**

        Returns the hop count limit associated with this datagram. The hop count
        limit is the number of nodes that are allowed to forward the IP packet
        before it expires and an error is sent back to the sender of the
        datagram. In IPv4, this value is usually known as "time to live" (TTL).

        If this datagram was received from the network, this is the remaining
        hop count of the datagram after reception and was decremented by 1 by
        each node that forwarded the packet. A value of -1 indicates that the
        hop limit count not be obtained.

        If this is an outgoing datagram, this is the value to be set in the IP
        header upon sending. A value of -1 indicates the operating system should
        choose the value.

        **See also** **setHopLimit** ().
        """
        ...

    def setDestination(
        self,
        address: typing.Union[QHostAddress, QHostAddress.SpecialAddress],
        port: int,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#setDestination

        **void QNetworkDatagram::setDestination(const QHostAddress & address ,
        quint16 port )**

        Sets the destination address associated with this datagram to be the
        address **address** and port number **port**. The destination address
        and port numbers are usually set by **QUdpSocket**  upon reception, so
        there's no need to call this function on a received datagram.

        For outgoing datagrams, this function can be used to set the address the
        datagram should be sent to. It can be the unicast address used to
        communicate with the peer or a broadcast or multicast address to send to
        a group of devices.

        **See also** **QUdpSocket::writeDatagram** (), **destinationAddress**
        (), **destinationPort** (), and **setSender** ().
        """
        ...

    def setSender(
        self,
        address: typing.Union[QHostAddress, QHostAddress.SpecialAddress],
        port: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#setSender

        **void QNetworkDatagram::setSender(const QHostAddress & address ,
        quint16 port = 0)**

        Sets the sender address associated with this datagram to be the address
        **address** and port number **port**. The sender address and port
        numbers are usually set by **QUdpSocket**  upon reception, so there's no
        need to call this function on a received datagram.

        For outgoing datagrams, this function can be used to set the address the
        datagram should carry. The address **address** must usually be one of
        the local addresses assigned to this machine, which can be obtained
        using **QNetworkInterface** . If left unset, the operating system will
        choose the most appropriate address to use given the destination in
        question.

        The port number **port** must be the port number associated with the
        socket, if there is one. The value of 0 can be used to indicate that the
        operating system should choose the port number.

        **See also** **QUdpSocket::writeDatagram** (), **senderAddress** (),
        **senderPort** (), and **setDestination** ().
        """
        ...

    def destinationPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#destinationPort

        **int QNetworkDatagram::destinationPort() const**

        Returns the port number of the destination associated with this
        datagram. For a datagram received from the network, it is the local port
        number that the peer node sent the datagram to. For an outgoing
        datagram, it is the peer port the datagram should be sent to.

        If no destination address was associated with this datagram, this
        function returns -1.

        **See also** **destinationAddress** (), **senderPort** (), and
        **setDestination** ().
        """
        ...

    def senderPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#senderPort

        **int QNetworkDatagram::senderPort() const**

        Returns the port number of the sender associated with this datagram. For
        a datagram received from the network, it is the port number that the
        peer node sent the datagram from. For an outgoing datagram, it is the
        local port the datagram should be sent from.

        If no sender address was associated with this datagram, this function
        returns -1.

        **See also** **senderAddress** (), **destinationPort** (), and
        **setSender** ().
        """
        ...

    def destinationAddress(self) -> QHostAddress:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#destinationAddress

        **QHostAddress QNetworkDatagram::destinationAddress() const**

        Returns the destination address associated with this datagram. For a
        datagram received from the network, it is the address the peer node sent
        the datagram to, which can either be a local address of this machine or
        a multicast or broadcast address. For an outgoing datagrams, it is the
        address the datagram should be sent to.

        If no destination address was set on this datagram, the returned object
        will report true to **QHostAddress::isNull** ().

        **See also** **senderAddress** (), **destinationPort** (), and
        **setDestination** ().
        """
        ...

    def senderAddress(self) -> QHostAddress:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#senderAddress

        **QHostAddress QNetworkDatagram::senderAddress() const**

        Returns the sender address associated with this datagram. For a datagram
        received from the network, it is the address of the peer node that sent
        the datagram. For an outgoing datagrams, it is the local address to be
        used when sending.

        If no sender address was set on this datagram, the returned object will
        report true to **QHostAddress::isNull** ().

        **See also** **destinationAddress** (), **senderPort** (), and
        **setSender** ().
        """
        ...

    def setInterfaceIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#setInterfaceIndex

        **void QNetworkDatagram::setInterfaceIndex(uint index )**

        Sets the interface index this datagram is associated with to **index**.
        The interface index is a positive number that uniquely identifies the
        network interface in the operating system. This number matches the value
        returned by **QNetworkInterface::index** () for the interface.

        It is usually not necessary to call this function on datagrams received
        from the network.

        If this is an outgoing packet, this is the index of the interface the
        datagram should be sent on. A value of 0 indicates that the operating
        system should choose the interface based on other factors.

        Note that the interface index can also be set with
        **QHostAddress::setScopeId** () for IPv6 destination addresses and then
        with **setDestination** (). If the scope ID set in the destination
        address and **index** are different and neither is zero, it is undefined
        which interface the operating system will send the datagram on.

        **See also** **interfaceIndex** () and setInterfaceIndex().
        """
        ...

    def interfaceIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#interfaceIndex

        **uint QNetworkDatagram::interfaceIndex() const**

        Returns the interface index this datagram is associated with. The
        interface index is a positive number that uniquely identifies the
        network interface in the operating system. This number matches the value
        returned by **QNetworkInterface::index** () for the interface.

        If this datagram was received from the network, this is the index of the
        interface that the packet was received from. If this is an outgoing
        datagram, this is the index of the interface that the datagram should be
        sent on.

        A value of 0 indicates that the interface index is unknown.

        **See also** **setInterfaceIndex** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#isNull

        **bool QNetworkDatagram::isNull() const**

        Returns true if this **QNetworkDatagram**  object is null. This function
        is the opposite of **isValid** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#isValid

        **bool QNetworkDatagram::isValid() const**

        Returns true if this **QNetworkDatagram**  object is valid. A valid
        **QNetworkDatagram**  object contains at least one sender or receiver
        address. Valid datagrams can contain empty payloads.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#clear

        **void QNetworkDatagram::clear()**

        Clears the payload data and metadata in this **QNetworkDatagram**
        object, resetting them to their default values.
        """
        ...

    def swap(self, other: "QNetworkDatagram") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkdatagram.html#swap

        **void QNetworkDatagram::swap(QNetworkDatagram & other )**

        Swaps this instance with **other**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QTextFrameFormat(QTextFormat):
    """
    https://doc.qt.io/qt-6/qtextframeformat.html

    **Detailed Description**

    A text frame groups together one or more blocks of text, providing a layer
    of structure larger than the paragraph. The format of a frame specifies how
    it is rendered and positioned on the screen. It does not directly specify
    the behavior of the text formatting within, but provides constraints on the
    layout of its children.

    The frame format defines the **width** () and **height** () of the frame on
    the screen. Each frame can have a **border** () that surrounds its contents
    with a rectangular box. The border is surrounded by a **margin** () around
    the frame, and the contents of the frame are kept separate from the border
    by the frame's **padding** (). This scheme is similar to the box model used
    by Cascading Style Sheets for HTML pages.

    ![](images/qtextframe-style.png)

    The **position** () of a frame is set using **setPosition** () and
    determines how it is located relative to the surrounding text.

    The validity of a QTextFrameFormat object can be determined with the
    **isValid** () function.

    **See also** **QTextFrame**  and **QTextBlockFormat** .
    """

    class BorderStyle(enum.Enum):
        BorderStyle_None: QTextFrameFormat = ...
        BorderStyle_Dotted: QTextFrameFormat = ...
        BorderStyle_Dashed: QTextFrameFormat = ...
        BorderStyle_Solid: QTextFrameFormat = ...
        BorderStyle_Double: QTextFrameFormat = ...
        BorderStyle_DotDash: QTextFrameFormat = ...
        BorderStyle_DotDotDash: QTextFrameFormat = ...
        BorderStyle_Groove: QTextFrameFormat = ...
        BorderStyle_Ridge: QTextFrameFormat = ...
        BorderStyle_Inset: QTextFrameFormat = ...
        BorderStyle_Outset: QTextFrameFormat = ...

    class Position(enum.Enum):
        InFlow: QTextFrameFormat = ...
        FloatLeft: QTextFrameFormat = ...
        FloatRight: QTextFrameFormat = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#QTextFrameFormat

        **QTextFrameFormat::QTextFrameFormat()**

        Constructs a text frame format object with the default properties.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTextFrameFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#QTextFrameFormat

        **QTextFrameFormat::QTextFrameFormat()**

        Constructs a text frame format object with the default properties.
        """
        ...

    def setRightMargin(self, amargin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setRightMargin

        **void QTextFrameFormat::setRightMargin(qreal margin )**

        Sets the frame's right **margin** in pixels.

        **See also** **rightMargin** ().
        """
        ...

    def setLeftMargin(self, amargin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setLeftMargin

        **void QTextFrameFormat::setLeftMargin(qreal margin )**

        Sets the frame's left **margin** in pixels.

        **See also** **leftMargin** ().
        """
        ...

    def setBottomMargin(self, amargin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setBottomMargin

        **void QTextFrameFormat::setBottomMargin(qreal margin )**

        Sets the frame's bottom **margin** in pixels.

        **See also** **bottomMargin** ().
        """
        ...

    def setTopMargin(self, amargin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setTopMargin

        **void QTextFrameFormat::setTopMargin(qreal margin )**

        Sets the frame's top **margin** in pixels.

        **See also** **topMargin** ().
        """
        ...

    def rightMargin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#rightMargin

        **qreal QTextFrameFormat::rightMargin() const**

        Returns the width of the frame's right margin in pixels.

        **See also** **setRightMargin** ().
        """
        ...

    def leftMargin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#leftMargin

        **qreal QTextFrameFormat::leftMargin() const**

        Returns the width of the frame's left margin in pixels.

        **See also** **setLeftMargin** ().
        """
        ...

    def bottomMargin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#bottomMargin

        **qreal QTextFrameFormat::bottomMargin() const**

        Returns the width of the frame's bottom margin in pixels.

        **See also** **setBottomMargin** ().
        """
        ...

    def topMargin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#topMargin

        **qreal QTextFrameFormat::topMargin() const**

        Returns the width of the frame's top margin in pixels.

        **See also** **setTopMargin** ().
        """
        ...

    def borderStyle(self) -> "QTextFrameFormat.BorderStyle":
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#borderStyle

        **QTextFrameFormat::BorderStyle QTextFrameFormat::borderStyle() const**

        Returns the style of the frame's border.

        **See also** **setBorderStyle** ().
        """
        ...

    def setBorderStyle(self, style: "QTextFrameFormat.BorderStyle") -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setBorderStyle

        **void QTextFrameFormat::setBorderStyle(QTextFrameFormat::BorderStyle
        style )**

        Sets the **style** of the frame's border.

        **See also** **borderStyle** ().
        """
        ...

    def borderBrush(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#borderBrush

        **QBrush QTextFrameFormat::borderBrush() const**

        Returns the brush used for the frame's border.

        **See also** **setBorderBrush** ().
        """
        ...

    def setBorderBrush(
        self, brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setBorderBrush

        **void QTextFrameFormat::setBorderBrush(const QBrush & brush )**

        Sets the **brush** used for the frame's border.

        **See also** **borderBrush** ().
        """
        ...

    def pageBreakPolicy(self) -> QTextFormat.PageBreakFlag:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#pageBreakPolicy

        **QTextFormat::PageBreakFlags QTextFrameFormat::pageBreakPolicy()
        const**

        Returns the currently set page break policy for the frame/table. The
        default is **QTextFormat::PageBreak_Auto** .

        **See also** **setPageBreakPolicy** ().
        """
        ...

    def setPageBreakPolicy(self, flags: QTextFormat.PageBreakFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setPageBreakPolicy

        **void QTextFrameFormat::setPageBreakPolicy(QTextFormat::PageBreakFlags
        policy )**

        Sets the page break policy for the frame/table to **policy**.

        **See also** **pageBreakPolicy** ().
        """
        ...

    @typing.overload
    def setHeight(self, aheight: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setHeight

        **void QTextFrameFormat::setHeight(const QTextLength & height )**

        Sets the frame's **height**.

        **See also** **height** ().
        """
        ...

    @typing.overload
    def setHeight(self, aheight: QTextLength) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setHeight-1

        **void QTextFrameFormat::setHeight(qreal height )**

        This is an overloaded function.

        Sets the frame's **height**.
        """
        ...

    def setPadding(self, apadding: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setPadding

        **void QTextFrameFormat::setPadding(qreal width )**

        Sets the **width** of the frame's internal padding in pixels.

        **See also** **padding** ().
        """
        ...

    def setMargin(self, amargin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setMargin

        **void QTextFrameFormat::setMargin(qreal margin )**

        Sets the frame's **margin** in pixels. This method also sets the left,
        right, top and bottom margins of the frame to the same value. The
        individual margins override the general margin.

        **See also** **margin** ().
        """
        ...

    def setBorder(self, aborder: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setBorder

        **void QTextFrameFormat::setBorder(qreal width )**

        Sets the **width** (in pixels) of the frame's border.

        **See also** **border** ().
        """
        ...

    def height(self) -> QTextLength:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#height

        **QTextLength QTextFrameFormat::height() const**

        Returns the height of the frame's border rectangle.

        **See also** **setHeight** ().
        """
        ...

    def width(self) -> QTextLength:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#width

        **QTextLength QTextFrameFormat::width() const**

        Returns the width of the frame's border rectangle.

        **See also** **setWidth** () and **QTextLength** .
        """
        ...

    @typing.overload
    def setWidth(self, length: QTextLength) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setWidth

        **void QTextFrameFormat::setWidth(const QTextLength & width )**

        Sets the frame's border rectangle's **width**.

        **See also** **width** () and **QTextLength** .
        """
        ...

    @typing.overload
    def setWidth(self, awidth: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setWidth-1

        **void QTextFrameFormat::setWidth(qreal width )**

        This is an overloaded function.

        Convenience method that sets the width of the frame's border rectangle's
        width to the specified fixed **width**.
        """
        ...

    def padding(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#padding

        **qreal QTextFrameFormat::padding() const**

        Returns the width of the frame's internal padding in pixels.

        **See also** **setPadding** ().
        """
        ...

    def margin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#margin

        **qreal QTextFrameFormat::margin() const**

        Returns the width of the frame's external margin in pixels.

        **See also** **setMargin** ().
        """
        ...

    def border(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#border

        **qreal QTextFrameFormat::border() const**

        Returns the width of the border in pixels.

        **See also** **setBorder** ().
        """
        ...

    def position(self) -> "QTextFrameFormat.Position":
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#position

        **QTextFrameFormat::Position QTextFrameFormat::position() const**

        Returns the positioning policy for frames with this frame format.

        **See also** **setPosition** ().
        """
        ...

    def setPosition(self, f: "QTextFrameFormat.Position") -> None:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#setPosition

        **void QTextFrameFormat::setPosition(QTextFrameFormat::Position policy
        )**

        Sets the **policy** for positioning frames with this frame format.

        **See also** **position** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextframeformat.html#isValid

        **bool QTextFrameFormat::isValid() const**

        Returns `true` if the format description is valid; otherwise returns
        `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNfc import *
import enum


class QNearFieldManager(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qnearfieldmanager.html

    **Detailed Description**

    NFC Forum devices support two modes of communications. The first mode, peer-
    to-peer communications, is used to communicate between two NFC Forum
    devices. The second mode, master/slave communications, is used to
    communicate between an NFC Forum device and an NFC Forum Tag or Contactless
    Card. The **targetDetected** () signal is emitted when a target device
    enters communications range. Communications can be initiated from the slot
    connected to this signal.

    NFC Forum devices generally operate as the master in master/slave
    communications. Some devices are also capable of operating as the slave, so
    called Card Emulation mode. In this mode the local NFC device emulates a NFC
    Forum Tag or Contactless Card.

    Applications can connect to the **targetDetected** () and **targetLost** ()
    signals to get notified when an NFC Forum Tag enters or leaves proximity.
    Before these signals are emitted target detection must be started with the
    **startTargetDetection** () function. Target detection can be stopped with
    the **stopTargetDetection** () function. When the target is no longer
    required the target should be deleted as other applications may be blocked
    from accessing the target.
    """

    class AdapterState(enum.Enum):
        Offline: QNearFieldManager = ...
        TurningOn: QNearFieldManager = ...
        Online: QNearFieldManager = ...
        TurningOff: QNearFieldManager = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#QNearFieldManager

        **QNearFieldManager::QNearFieldManager(QObject * parent = nullptr)**

        Constructs a new near field manager with **parent**.
        """
        ...

    def setUserInformation(self, message: str) -> None:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#setUserInformation

        **[since 6.2] void QNearFieldManager::setUserInformation(const QString &
        message )**

        Sets the message shown to the user by the system. If the target
        detection is running the **message** will be updated immediately and can
        be used as a progress message. The last message set before a call to
        **startTargetDetection** () without an error message is used as a
        success message. If the target detection is not running the **message**
        will be used as the initial message when the next detection is started.
        By default no message is shown to the user.

        **Note:** Currently, this function only has an effect on iOS because a
        popup is shown by the system during the scan. On iOS, this **message**
        is mapped to the alert message which is shown upon successful completion
        of the scan. Other platforms will ignore **message**.

        This function was introduced in Qt 6.2.

        **See also** **startTargetDetection** () and **stopTargetDetection** ().
        """
        ...

    def isEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#isEnabled

        **[since 6.2] bool QNearFieldManager::isEnabled() const**

        Returns `true` if the device has a NFC adapter and it is turned on;
        otherwise returns `false`.

        This function was introduced in Qt 6.2.

        **See also** **isSupported** ().
        """
        ...

    def isSupported(self, accessMethod: "QNearFieldTarget.AccessMethod" = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#isSupported

        **[since 5.12] bool
        QNearFieldManager::isSupported(QNearFieldTarget::AccessMethod
        accessMethod = QNearFieldTarget::AnyAccess) const**

        Returns `true` if the underlying device has a NFC adapter; otherwise
        returns `false`. If an **accessMethod** is given, the function returns
        `true` only if the NFC adapter supports the given **accessMethod**.

        This function was introduced in Qt 5.12.

        **See also** **isEnabled** ().
        """
        ...

    def stopTargetDetection(self, errorMessage: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#stopTargetDetection

        **void QNearFieldManager::stopTargetDetection(const QString &
        errorMessage = QString())**

        Stops detecting targets. The **targetDetected** () signal will no longer
        be emitted until another call to **startTargetDetection** () is made.
        Targets detected before are still valid.

        If an **errorMessage** is provided, this is a hint to the system that
        the goal, the application had, was not reached. The **errorMessage** and
        a matching error icon are shown to the user. Calling this function with
        an empty **errorMessage** , implies a successful operation end;
        otherwise an **errorMessage** should be passed to this function.

        **Note:** Currently, **errorMessage** only has an effect on iOS because
        a popup is shown by the system during the scan where the
        **errorMessage** is visible. Other platforms will ignore this parameter.

        **See also** **setUserInformation** ().
        """
        ...

    def startTargetDetection(
        self, accessMethod: "QNearFieldTarget.AccessMethod"
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#startTargetDetection

        **bool
        QNearFieldManager::startTargetDetection(QNearFieldTarget::AccessMethod
        accessMethod )**

        Starts detecting targets and returns `true` if target detection is
        successfully started; otherwise returns `false`. Causes the
        **targetDetected** () signal to be emitted when a target is within
        proximity. Only tags with the given **accessMethod** will be delivered.
        Active detection continues until **stopTargetDetection** () has been
        called.

        To detect targets with a different **accessMethod** ,
        **stopTargetDetection** () must be called first.

        **See also** **stopTargetDetection** ().
        """
        ...

    @property
    def adapterStateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#adapterStateChanged

        **[signal, since 5.12] void
        QNearFieldManager::adapterStateChanged(QNearFieldManager::AdapterState
        state )**

        This signal is emitted whenever the **state** of the NFC adapter
        changed.

        **Note:** Currently, this signal is only emitted on Android.

        This function was introduced in Qt 5.12.
        """
        ...

    @property
    def targetDetected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#targetDetected

        **[signal] void QNearFieldManager::targetDetected(QNearFieldTarget *
        target )**

        This signal is emitted whenever a target is detected. The **target**
        parameter represents the detected target.

        This signal will be emitted for all detected targets.

        **QNearFieldManager**  maintains ownership of **target** , however, it
        will not be destroyed until the **QNearFieldManager**  destructor is
        called. Ownership may be transferred by calling **setParent** ().

        Do not delete **target** from the slot connected to this signal, instead
        call **deleteLater** ().

        **Note:** that if **target** is deleted before it moves out of proximity
        the **targetLost** () signal will not be emitted.

        **See also** **targetLost** ().
        """
        ...

    @property
    def targetDetectionStopped(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#targetDetectionStopped

        **[signal, since 6.2] void QNearFieldManager::targetDetectionStopped()**

        This signal is emitted whenever the target detection is stopped.

        **Note:** Mostly this signal is emitted when **stopTargetDetection** ()
        has been called. Additionally the user is able to stop the detection on
        iOS within a popup shown by the system during the scan, which also leads
        to emitting this signal.

        This function was introduced in Qt 6.2.
        """
        ...

    @property
    def targetLost(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnearfieldmanager.html#targetLost

        **[signal] void QNearFieldManager::targetLost(QNearFieldTarget * target
        )**

        This signal is emitted whenever a target moves out of proximity. The
        **target** parameter represents the lost target.

        Do not delete **target** from the slot connected to this signal, instead
        use **deleteLater** ().

        **See also** **QNearFieldTarget::disconnected** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QRotationReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qrotationreading.html

    **Detailed Description**

    **QRotationReading Units**

    The rotation reading contains 3 angles, measured in degrees that define the
    orientation of the device in three-dimensional space. These angles are
    similar to yaw, pitch and roll but are defined using only right hand
    rotation with axes as defined by the right hand cartesian coordinate system.

    ![](images/sensors-rotation.jpg)

    The three angles are applied to the device in the following order.

    * Right-handed rotation z (-180, 180]. Starting from the y-axis and
    incrementing in the counter-clockwise direction.
      * Right-handed rotation x
    [-90, 90]. Starting from the new (once-rotated) y-axis and incrementing
    towards the z-axis.
      * Right-handed rotation y (-180, 180]. Starting from
    the new (twice-rotated) z-axis and incrementing towards the x-axis.

    Here is a visualization showing the order in which angles are applied.

    ![](images/sensors-rotation-anim.gif)

    The 0 point for the z angle is defined as a fixed, external entity and is
    device-specific. While magnetic North is typically used as this reference
    point it may not be. Do not attempt to compare values for the z angle
    between devices or even on the same device if it has moved a significant
    distance.

    If the device cannot detect a fixed, external entity the z angle will always
    be 0 and the **QRotationSensor::hasZ**  property will be set to false.

    The 0 point for the x and y angles are defined as when the x and y axes of
    the device are oriented towards the horizon. Here is an example of how the x
    value will change with device movement.

    ![](images/sensors-rotation2.jpg)

    Here is an example of how the y value will change with device movement.

    ![](images/sensors-rotation3.jpg)

    Note that when x is 90 or -90, values for z and y achieve rotation around
    the same axis (due to the order of operations). In this case the y rotation
    will be 0.
    """

    def setFromEuler(self, x: float, y: float, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qrotationreading.html#setFromEuler

        **[since 5.0] void QRotationReading::setFromEuler(qreal x , qreal y ,
        qreal z )**

        Sets the rotation from three euler angles.

        This is to be called from the backend.

        The angles are measured in degrees. The order of the rotations matters,
        as first the **z** rotation is applied, then the **x** rotation and
        finally the **y** rotation.

        This function was introduced in Qt 5.0.
        """
        ...

    def z(self) -> float:
        """
        https://doc.qt.io/qt-6/qrotationreading.html#z-prop

        **[read-only] z : const qreal**

        This property holds the rotation around the z axis.

        Measured as degrees.

        **Access functions:**

        qreal **z** () const

        **See also** **QRotationReading Units** .

        **Member Function Documentation**
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qrotationreading.html#y-prop

        **[read-only] y : const qreal**

        This property holds the rotation around the y axis.

        Measured as degrees.

        **Access functions:**

        qreal **y** () const

        **See also** **QRotationReading Units** .
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qrotationreading.html#x-prop

        **[read-only] x : const qreal**

        This property holds the rotation around the x axis.

        Measured as degrees.

        **Access functions:**

        qreal **x** () const

        **See also** **QRotationReading Units** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore


class QInputMethodQueryEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qinputmethodqueryevent.html

    **Detailed Description**

    It is used by the input method to query a set of properties of the object to
    be able to support complex input method operations as support for
    surrounding text and reconversions.

    **queries** () specifies which properties are queried.

    The object should call **setValue** () on the event to fill in the requested
    data before calling **accept** ().
    """

    def __init__(self, queries: QtCore.Qt.InputMethodQuery) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethodqueryevent.html#QInputMethodQueryEven
        t-2

        **QInputMethodQueryEvent::QInputMethodQueryEvent(Qt::InputMethodQueries
        queries )**

        Constructs a query event for properties given by **queries**.
        """
        ...

    def clone(self) -> "QInputMethodQueryEvent":
        ...

    def value(self, query: QtCore.Qt.InputMethodQuery) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qinputmethodqueryevent.html#value

        **QVariant QInputMethodQueryEvent::value(Qt::InputMethodQuery query )
        const**

        Returns value of the property **query**.

        **See also** **setValue** ().
        """
        ...

    def setValue(self, query: QtCore.Qt.InputMethodQuery, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethodqueryevent.html#setValue

        **void QInputMethodQueryEvent::setValue(Qt::InputMethodQuery query ,
        const QVariant & value )**

        Sets property **query** to **value**.

        **See also** **value** ().
        """
        ...

    def queries(self) -> QtCore.Qt.InputMethodQuery:
        """
        https://doc.qt.io/qt-6/qinputmethodqueryevent.html#queries

        **Qt::InputMethodQueries QInputMethodQueryEvent::queries() const**

        Returns the properties queried by the event.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QSslDiffieHellmanParameters(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html

    **Detailed Description**

    QSslDiffieHellmanParameters provides an interface for setting Diffie-Hellman
    parameters to servers based on **QSslSocket** .

    **See also** **QSslSocket** , **QSslCipher** , and **QSslConfiguration** .
    """

    class Error(enum.Enum):
        NoError: QSslDiffieHellmanParameters = ...
        InvalidInputDataError: QSslDiffieHellmanParameters = ...
        UnsafeParametersError: QSslDiffieHellmanParameters = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#QSslDiffieHellma
        nParameters

        **QSslDiffieHellmanParameters::QSslDiffieHellmanParameters()**

        Constructs an empty QSslDiffieHellmanParameters instance.

        If an empty QSslDiffieHellmanParameters instance is set on a
        **QSslConfiguration**  object, Diffie-Hellman negotiation will be
        disabled.

        **See also** **isValid** () and **QSslConfiguration** .
        """
        ...

    @typing.overload
    def __init__(self, other: "QSslDiffieHellmanParameters") -> None:
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#QSslDiffieHellma
        nParameters-1

        **QSslDiffieHellmanParameters::QSslDiffieHellmanParameters(const
        QSslDiffieHellmanParameters & other )**

        Constructs an identical copy of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#errorString

        **QString QSslDiffieHellmanParameters::errorString() const**

        Returns a human-readable description of the error that caused the
        **QSslDiffieHellmanParameters**  object to be invalid.
        """
        ...

    def error(self) -> "QSslDiffieHellmanParameters.Error":
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#error

        **QSslDiffieHellmanParameters::Error
        QSslDiffieHellmanParameters::error() const**

        Returns the error that caused the **QSslDiffieHellmanParameters**
        object to be invalid.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#isValid

        **bool QSslDiffieHellmanParameters::isValid() const**

        Returns `true` if this is a valid **QSslDiffieHellmanParameters** ;
        otherwise false.

        This method should be used after constructing a
        **QSslDiffieHellmanParameters**  object to determine its validity.

        If a **QSslDiffieHellmanParameters**  object is not valid, you can use
        the **error** () method to determine what error prevented the object
        from being constructed.

        **See also** **error** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#isEmpty

        **bool QSslDiffieHellmanParameters::isEmpty() const**

        Returns `true` if this is a an empty **QSslDiffieHellmanParameters**
        instance.

        Setting an empty **QSslDiffieHellmanParameters**  instance on a
        **QSslSocket** -based server will disable Diffie-Hellman key exchange.
        """
        ...

    @typing.overload
    @staticmethod
    def fromEncoded(
        encoded: QtCore.QByteArray, encoding: QSsl.EncodingFormat = ...
    ) -> "QSslDiffieHellmanParameters":
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#fromEncoded

        **[static] QSslDiffieHellmanParameters
        QSslDiffieHellmanParameters::fromEncoded(const QByteArray & encoded ,
        QSsl::EncodingFormat encoding = QSsl::Pem)**

        Constructs a **QSslDiffieHellmanParameters**  object using the byte
        array **encoded** in either PEM or DER form as specified by
        **encoding**.

        Use the **isValid** () method on the returned object to check whether
        the Diffie-Hellman parameters were valid and loaded correctly.

        **See also** **isValid** () and **QSslConfiguration** .
        """
        ...

    @typing.overload
    @staticmethod
    def fromEncoded(
        device: QtCore.QIODevice, encoding: QSsl.EncodingFormat = ...
    ) -> "QSslDiffieHellmanParameters":
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#fromEncoded-1

        **[static] QSslDiffieHellmanParameters
        QSslDiffieHellmanParameters::fromEncoded(QIODevice * device ,
        QSsl::EncodingFormat encoding = QSsl::Pem)**

        Constructs a **QSslDiffieHellmanParameters**  object by reading from
        **device** in either PEM or DER form as specified by **encoding**.

        Use the **isValid** () method on the returned object to check whether
        the Diffie-Hellman parameters were valid and loaded correctly.

        In particular, if **device** is `nullptr` or not open for reading, an
        invalid object will be returned.

        **See also** **isValid** () and **QSslConfiguration** .
        """
        ...

    @staticmethod
    def defaultParameters() -> "QSslDiffieHellmanParameters":
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#defaultParameter
        s

        **[static] QSslDiffieHellmanParameters
        QSslDiffieHellmanParameters::defaultParameters()**

        Returns the default **QSslDiffieHellmanParameters**  used by
        **QSslSocket** .

        This is currently the 1024-bit MODP group from RFC 2459, also known as
        the Second Oakley Group.
        """
        ...

    def swap(self, other: "QSslDiffieHellmanParameters") -> None:
        """
        https://doc.qt.io/qt-6/qssldiffiehellmanparameters.html#swap

        **void QSslDiffieHellmanParameters::swap(QSslDiffieHellmanParameters &
        other )**

        Swaps this **QSslDiffieHellmanParameters**  with **other**. This
        function is very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QNetworkInformation(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qnetworkinformation.html

    **Detailed Description**

    QNetworkInformation provides a cross-platform interface to network-related
    information through plugins.

    Various plugins can have various functionality supported, and so you can
    **load** () plugins based on which features are needed.

    QNetworkInformation is a singleton and stays alive from the first successful
    **load** () until destruction of the **QCoreApplication**  object. If you
    destroy and re-create the **QCoreApplication**  object you must call
    **load** () again.

    **See also** **QNetworkInformation::Feature** .
    """

    class Feature(enum.Enum):
        Reachability: QNetworkInformation = ...
        CaptivePortal: QNetworkInformation = ...

    class Reachability(enum.Enum):
        Unknown: QNetworkInformation = ...
        Disconnected: QNetworkInformation = ...
        Local: QNetworkInformation = ...
        Site: QNetworkInformation = ...
        Online: QNetworkInformation = ...

    def isBehindCaptivePortal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkinformation.html#isBehindCaptivePortal-
        prop

        **[read-only, since 6.2] isBehindCaptivePortal : const bool**

        Lets you know if the user's device is behind a captive portal.

        This property indicates if the user's device is currently known to be
        behind a captive portal. This functionality relies on the operating
        system's detection of captive portals and is not supported on systems
        that don't report this. On systems where this is not supported this will
        always return `false`.

        This property was introduced in Qt 6.2.

        **Access functions:**

        bool **isBehindCaptivePortal** () const

        **Notifier signal:**

        void **isBehindCaptivePortalChanged** (bool **state** )
        """
        ...

    @staticmethod
    def instance() -> "QNetworkInformation":
        """
        https://doc.qt.io/qt-6/qnetworkinformation.html#instance

        **[static] QNetworkInformation *QNetworkInformation::instance()**

        Returns a pointer to the instance of the **QNetworkInformation** , if
        any.

        **See also** **load** ().
        """
        ...

    @staticmethod
    def availableBackends() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qnetworkinformation.html#availableBackends

        **[static] QStringList QNetworkInformation::availableBackends()**

        Returns a list of the names of all currently available backends.
        """
        ...

    @typing.overload
    @staticmethod
    def load(backend: str) -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkinformation.html#load

        **[static] bool QNetworkInformation::load(QStringView backend )**

        Attempts to load a backend whose name matches **backend** (case
        insensitively).

        Returns `true` if it managed to load the requested backend or if it was
        already loaded. Returns `false` otherwise

        **See also** **instance** .
        """
        ...

    @typing.overload
    @staticmethod
    def load(features: "QNetworkInformation.Feature") -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkinformation.html#load-1

        **[static] bool QNetworkInformation::load(QNetworkInformation::Features
        features )**

        Load a backend which supports **features**.

        Returns `true` if it managed to load the requested backend or if it was
        already loaded. Returns `false` otherwise

        **See also** **instance** .
        """
        ...

    def supports(self, features: "QNetworkInformation.Feature") -> bool:
        """
        https://doc.qt.io/qt-6/qnetworkinformation.html#supports

        **bool QNetworkInformation::supports(QNetworkInformation::Features
        features ) const**

        Returns `true` if the currently loaded backend supports **features**.
        """
        ...

    def backendName(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkinformation.html#backendName

        **QString QNetworkInformation::backendName() const**

        Returns the name of the currently loaded backend.
        """
        ...

    def reachability(self) -> "QNetworkInformation.Reachability":
        """
        https://doc.qt.io/qt-6/qnetworkinformation.html#reachability-prop

        **[read-only] reachability : const Reachability**

        This property holds the current state of the system's network
        connectivity.

        Indicates the level of connectivity that can be expected. Do note that
        this is only based on what the plugin/operating system reports. In
        certain scenarios this is known to be wrong. For example, on Windows the
        'Online' check, by default, is performed by Windows connecting to a
        Microsoft-owned server. If this server is for any reason blocked then it
        will assume it does not have Online reachability. Because of this you
        should not use this as a pre-check before attempting to make a
        connection.

        **Access functions:**

        QNetworkInformation::Reachability **reachability** () const

        **Notifier signal:**

        void **reachabilityChanged** (QNetworkInformation::Reachability
        **newReachability** )

        **Member Function Documentation**
        """
        ...

    @property
    def isBehindCaptivePortalChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def reachabilityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...
